# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/status.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2
from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2
from machinetalk.protobuf import preview_pb2 as machinetalk_dot_protobuf_dot_preview__pb2
from machinetalk.protobuf import emcclass_pb2 as machinetalk_dot_protobuf_dot_emcclass__pb2
from machinetalk.protobuf import motcmds_pb2 as machinetalk_dot_protobuf_dot_motcmds__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/status.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n!machinetalk/protobuf/status.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\x1a machinetalk/protobuf/types.proto\x1a\"machinetalk/protobuf/preview.proto\x1a#machinetalk/protobuf/emcclass.proto\x1a\"machinetalk/protobuf/motcmds.proto\"\xc6\x01\n\x0b\x45mcToolData\x12\r\n\x05index\x18\x01 \x02(\x05\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x10\n\x08\x64iameter\x18\x0c \x01(\x01\x12\x12\n\nfrontangle\x18\r \x01(\x01\x12\x11\n\tbackangle\x18\x0e \x01(\x01\x12\x13\n\x0borientation\x18\x0f \x01(\x05\x12%\n\x06offset\x18\x10 \x01(\x0b\x32\x15.machinetalk.Position\x12\x0f\n\x07\x63omment\x18\x11 \x01(\t\x12\x0e\n\x06pocket\x18\x12 \x01(\x05:\x06\x92?\x03H\xcc\x08\"\xd5\x02\n\x13\x45mcStatusMotionAxis\x12\r\n\x05index\x18\x01 \x02(\x05\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\r\n\x05\x66\x61ult\x18\x03 \x01(\x08\x12\x16\n\x0e\x66\x65rror_current\x18\x04 \x01(\x01\x12\x17\n\x0f\x66\x65rror_highmark\x18\x05 \x01(\x01\x12\r\n\x05homed\x18\x06 \x01(\x08\x12\x0e\n\x06homing\x18\x07 \x01(\x08\x12\r\n\x05inpos\x18\x08 \x01(\x08\x12\r\n\x05input\x18\t \x01(\x01\x12\x16\n\x0emax_hard_limit\x18\n \x01(\x08\x12\x16\n\x0emax_soft_limit\x18\x0b \x01(\x08\x12\x16\n\x0emin_hard_limit\x18\x0c \x01(\x08\x12\x16\n\x0emin_soft_limit\x18\r \x01(\x08\x12\x0e\n\x06output\x18\x0e \x01(\x01\x12\x17\n\x0foverride_limits\x18\x0f \x01(\x08\x12\x10\n\x08velocity\x18\x10 \x01(\x01:\x06\x92?\x03H\xcd\x08\"\xa6\x02\n\x13\x45mcStatusConfigAxis\x12\r\n\x05index\x18\x01 \x02(\x05\x12+\n\taxis_type\x18\x02 \x01(\x0e\x32\x18.machinetalk.EmcAxisType\x12\x10\n\x08\x62\x61\x63klash\x18\x03 \x01(\x01\x12\x12\n\nmax_ferror\x18\x04 \x01(\x01\x12\x1a\n\x12max_position_limit\x18\x05 \x01(\x01\x12\x12\n\nmin_ferror\x18\x06 \x01(\x01\x12\x1a\n\x12min_position_limit\x18\x07 \x01(\x01\x12\x15\n\rhome_sequence\x18\t \x01(\x05\x12\x18\n\x10max_acceleration\x18\n \x01(\x01\x12\x14\n\x0cmax_velocity\x18\x0b \x01(\x01\x12\x12\n\nincrements\x18\x0c \x01(\t:\x06\x92?\x03H\xce\x08\"?\n\x13\x45mcProgramExtension\x12\r\n\x05index\x18\x01 \x02(\x05\x12\x11\n\textension\x18\x02 \x01(\t:\x06\x92?\x03H\xcf\x08\"9\n\x11\x45mcStatusAnalogIO\x12\r\n\x05index\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x01:\x06\x92?\x03H\xd0\x08\":\n\x12\x45mcStatusDigitalIO\x12\r\n\x05index\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x08:\x06\x92?\x03H\xd1\x08\"6\n\x0e\x45mcStatusLimit\x12\r\n\x05index\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x06\x92?\x03H\xd2\x08\"6\n\x0e\x45mcStatusGCode\x12\r\n\x05index\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x06\x92?\x03H\xd3\x08\"6\n\x0e\x45mcStatusMCode\x12\r\n\x05index\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x06\x92?\x03H\xd4\x08\"8\n\x10\x45mcStatusSetting\x12\r\n\x05index\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x01:\x06\x92?\x03H\xd5\x08\"\xba\t\n\x0f\x45mcStatusConfig\x12\x1c\n\x14\x64\x65\x66\x61ult_acceleration\x18\x01 \x01(\x01\x12\x0c\n\x04\x61xes\x18\x03 \x01(\x05\x12.\n\x04\x61xis\x18\x04 \x03(\x0b\x32 .machinetalk.EmcStatusConfigAxis\x12\x11\n\taxis_mask\x18\x05 \x01(\x05\x12\x12\n\ncycle_time\x18\x06 \x01(\x01\x12\r\n\x05\x64\x65\x62ug\x18\x07 \x01(\x05\x12\x37\n\x0fkinematics_type\x18\x08 \x01(\x0e\x32\x1e.machinetalk.EmcKinematicsType\x12\x18\n\x10max_acceleration\x18\n \x01(\x01\x12\x14\n\x0cmax_velocity\x18\x0b \x01(\x01\x12\x35\n\x0clinear_units\x18\x0c \x01(\x0e\x32\x1f.machinetalk.EmcLinearUnitsType\x12\x18\n\x10\x64\x65\x66\x61ult_velocity\x18\r \x01(\x01\x12;\n\x11program_extension\x18\x0e \x03(\x0b\x32 .machinetalk.EmcProgramExtension\x12;\n\x0fposition_offset\x18\x0f \x01(\x0e\x32\".machinetalk.EmcPositionOffsetType\x12?\n\x11position_feedback\x18\x10 \x01(\x0e\x32$.machinetalk.EmcPositionFeedbackType\x12\x19\n\x11max_feed_override\x18\x11 \x01(\x01\x12\x19\n\x11min_feed_override\x18\x12 \x01(\x01\x12\x1c\n\x14max_spindle_override\x18\x13 \x01(\x01\x12\x1c\n\x14min_spindle_override\x18\x14 \x01(\x01\x12\x1d\n\x15\x64\x65\x66\x61ult_spindle_speed\x18\x15 \x01(\x01\x12\x1f\n\x17\x64\x65\x66\x61ult_linear_velocity\x18\x16 \x01(\x01\x12\x14\n\x0cmin_velocity\x18\x17 \x01(\x01\x12\x1b\n\x13max_linear_velocity\x18\x18 \x01(\x01\x12\x1b\n\x13min_linear_velocity\x18\x19 \x01(\x01\x12 \n\x18\x64\x65\x66\x61ult_angular_velocity\x18\x1a \x01(\x01\x12\x1c\n\x14max_angular_velocity\x18\x1b \x01(\x01\x12\x1c\n\x14min_angular_velocity\x18\x1c \x01(\x01\x12\x12\n\nincrements\x18\x1d \x01(\t\x12\r\n\x05grids\x18\x1e \x01(\t\x12\r\n\x05lathe\x18\x1f \x01(\x08\x12\x10\n\x08geometry\x18  \x01(\t\x12\x13\n\x0b\x61rcdivision\x18! \x01(\r\x12\x17\n\x0fno_force_homing\x18\" \x01(\x08\x12\x13\n\x0bremote_path\x18# \x01(\t\x12\x31\n\ntime_units\x18$ \x01(\x0e\x32\x1d.machinetalk.EmcTimeUnitsType\x12\x0c\n\x04name\x18% \x01(\t\x12\x37\n\x0cuser_command\x18& \x03(\x0b\x32!.machinetalk.EmcStatusUserCommand\x12\x37\n\rangular_units\x18\' \x01(\x0e\x32 .machinetalk.EmcAngularUnitsType:\x06\x92?\x03H\xd6\x08\"\xfb\x0b\n\x0f\x45mcStatusMotion\x12\x14\n\x0c\x61\x63tive_queue\x18\x01 \x01(\x05\x12.\n\x0f\x61\x63tual_position\x18\x02 \x01(\x0b\x32\x15.machinetalk.Position\x12\x1d\n\x15\x61\x64\x61ptive_feed_enabled\x18\x03 \x01(\x08\x12+\n\x03\x61in\x18\x04 \x03(\x0b\x32\x1e.machinetalk.EmcStatusAnalogIO\x12,\n\x04\x61out\x18\x05 \x03(\x0b\x32\x1e.machinetalk.EmcStatusAnalogIO\x12.\n\x04\x61xis\x18\x06 \x03(\x0b\x32 .machinetalk.EmcStatusMotionAxis\x12\x14\n\x0c\x62lock_delete\x18\x07 \x01(\x08\x12\x14\n\x0c\x63urrent_line\x18\x08 \x01(\x05\x12\x13\n\x0b\x63urrent_vel\x18\t \x01(\x01\x12\x12\n\ndelay_left\x18\n \x01(\x01\x12,\n\x03\x64in\x18\x0b \x03(\x0b\x32\x1f.machinetalk.EmcStatusDigitalIO\x12\x16\n\x0e\x64istance_to_go\x18\x0c \x01(\x01\x12-\n\x04\x64out\x18\r \x03(\x0b\x32\x1f.machinetalk.EmcStatusDigitalIO\x12\"\n\x03\x64tg\x18\x0e \x01(\x0b\x32\x15.machinetalk.Position\x12\x0f\n\x07\x65nabled\x18\x0f \x01(\x08\x12\x19\n\x11\x66\x65\x65\x64_hold_enabled\x18\x10 \x01(\x08\x12\x1d\n\x15\x66\x65\x65\x64_override_enabled\x18\x11 \x01(\x08\x12\x10\n\x08\x66\x65\x65\x64rate\x18\x12 \x01(\x01\x12+\n\tg5x_index\x18\x13 \x01(\x0e\x32\x18.machinetalk.OriginIndex\x12)\n\ng5x_offset\x18\x14 \x01(\x0b\x32\x15.machinetalk.Position\x12)\n\ng92_offset\x18\x15 \x01(\x0b\x32\x15.machinetalk.Position\x12\n\n\x02id\x18\x17 \x01(\x05\x12\r\n\x05inpos\x18\x18 \x01(\x08\x12\x34\n\x15joint_actual_position\x18\x19 \x01(\x0b\x32\x15.machinetalk.Position\x12-\n\x0ejoint_position\x18\x1a \x01(\x0b\x32\x15.machinetalk.Position\x12*\n\x05limit\x18\x1b \x03(\x0b\x32\x1b.machinetalk.EmcStatusLimit\x12\x13\n\x0bmotion_line\x18\x1c \x01(\x05\x12,\n\x0bmotion_type\x18\x1d \x01(\x0e\x32\x17.machinetalk.MotionType\x12\x37\n\x0bmotion_mode\x18\x1e \x01(\x0e\x32\".machinetalk.EmcTrajectoryModeType\x12\x0e\n\x06paused\x18\x1f \x01(\x08\x12\'\n\x08position\x18  \x01(\x0b\x32\x15.machinetalk.Position\x12\x15\n\rprobe_tripped\x18! \x01(\x08\x12\x11\n\tprobe_val\x18\" \x01(\x05\x12.\n\x0fprobed_position\x18# \x01(\x0b\x32\x15.machinetalk.Position\x12\x0f\n\x07probing\x18$ \x01(\x08\x12\r\n\x05queue\x18% \x01(\x05\x12\x12\n\nqueue_full\x18& \x01(\x08\x12\x13\n\x0brotation_xy\x18\' \x01(\x01\x12\x15\n\rspindle_brake\x18( \x01(\x08\x12\x19\n\x11spindle_direction\x18) \x01(\x05\x12\x17\n\x0fspindle_enabled\x18* \x01(\x08\x12\x1a\n\x12spindle_increasing\x18+ \x01(\x05\x12 \n\x18spindle_override_enabled\x18, \x01(\x08\x12\x15\n\rspindle_speed\x18- \x01(\x01\x12\x13\n\x0bspindlerate\x18. \x01(\x01\x12&\n\x05state\x18/ \x01(\x0e\x32\x17.machinetalk.RCS_STATUS\x12\x14\n\x0cmax_velocity\x18\x30 \x01(\x01\x12\x18\n\x10max_acceleration\x18\x31 \x01(\x01\x12\x11\n\trapidrate\x18\x32 \x01(\x01:\x06\x92?\x03H\xd7\x08\"\xee\x01\n\x0b\x45mcStatusIo\x12\r\n\x05\x65stop\x18\x01 \x01(\x08\x12\r\n\x05\x66lood\x18\x02 \x01(\x08\x12\x0c\n\x04lube\x18\x03 \x01(\x08\x12\x12\n\nlube_level\x18\x04 \x01(\x08\x12\x0c\n\x04mist\x18\x05 \x01(\x08\x12*\n\x0btool_offset\x18\x08 \x01(\x0b\x32\x15.machinetalk.Position\x12,\n\ntool_table\x18\t \x03(\x0b\x32\x18.machinetalk.EmcToolData\x12\x16\n\x0epocket_prepped\x18\n \x01(\x05\x12\x17\n\x0ftool_in_spindle\x18\x0b \x01(\x05:\x06\x92?\x03H\xd8\x08\"\xc7\x02\n\rEmcStatusTask\x12\x1a\n\x12\x65\x63ho_serial_number\x18\x01 \x01(\x05\x12\x35\n\nexec_state\x18\x02 \x01(\x0e\x32!.machinetalk.EmcTaskExecStateType\x12\x0c\n\x04\x66ile\x18\x03 \x01(\t\x12\x15\n\rinput_timeout\x18\x04 \x01(\x08\x12\x15\n\roptional_stop\x18\x05 \x01(\x08\x12\x11\n\tread_line\x18\x06 \x01(\x05\x12/\n\ttask_mode\x18\x07 \x01(\x0e\x32\x1c.machinetalk.EmcTaskModeType\x12\x13\n\x0btask_paused\x18\x08 \x01(\x05\x12\x31\n\ntask_state\x18\t \x01(\x0e\x32\x1d.machinetalk.EmcTaskStateType\x12\x13\n\x0btotal_lines\x18\n \x01(\x05:\x06\x92?\x03H\xd9\x08\"\xe4\x02\n\x0f\x45mcStatusInterp\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12+\n\x06gcodes\x18\x02 \x03(\x0b\x32\x1b.machinetalk.EmcStatusGCode\x12\x35\n\x0cinterp_state\x18\x03 \x01(\x0e\x32\x1f.machinetalk.EmcInterpStateType\x12?\n\x13interpreter_errcode\x18\x04 \x01(\x0e\x32\".machinetalk.EmcInterpExitCodeType\x12+\n\x06mcodes\x18\x05 \x03(\x0b\x32\x1b.machinetalk.EmcStatusMCode\x12/\n\x08settings\x18\x06 \x03(\x0b\x32\x1d.machinetalk.EmcStatusSetting\x12\x35\n\rprogram_units\x18\x07 \x01(\x0e\x32\x1e.machinetalk.EmcCanonUnitsType:\x06\x92?\x03H\xda\x08\"\xe2\x03\n\x14\x45mcCommandParameters\x12\r\n\x05index\x18\x01 \x01(\r\x12\x13\n\x0b\x64\x65\x62ug_level\x18\x02 \x01(\r\x12\x13\n\x0bline_number\x18\x03 \x01(\x05\x12\r\n\x05scale\x18\x04 \x01(\x01\x12\x10\n\x08velocity\x18\x05 \x01(\x01\x12\x10\n\x08\x64istance\x18\x06 \x01(\x01\x12\r\n\x05value\x18\x07 \x01(\x01\x12\x0e\n\x06\x65nable\x18\x08 \x01(\x08\x12\x0f\n\x07\x63ommand\x18\t \x01(\t\x12\x0c\n\x04path\x18\n \x01(\t\x12/\n\ttask_mode\x18\x64 \x01(\x0e\x32\x1c.machinetalk.EmcTaskModeType\x12\x31\n\ntask_state\x18\x65 \x01(\x0e\x32\x1d.machinetalk.EmcTaskStateType\x12\x35\n\ttraj_mode\x18\x66 \x01(\x0e\x32\".machinetalk.EmcTrajectoryModeType\x12\"\n\x04pose\x18g \x01(\x0b\x32\x14.machinetalk.EmcPose\x12+\n\ttool_data\x18h \x01(\x0b\x32\x18.machinetalk.EmcToolData\x12,\n\ntool_table\x18i \x03(\x0b\x32\x18.machinetalk.EmcToolData:\x06\x92?\x03H\xdb\x08\">\n\x14\x45mcStatusUserCommand\x12\r\n\x05index\x18\x01 \x02(\x05\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t:\x06\x92?\x03H\xdc\x08\"\xa7\x02\n\x0b\x45mcStatusUI\x12\x1d\n\x15spindle_brake_visible\x18\x01 \x01(\x08\x12\x1a\n\x12spindle_cw_visible\x18\x02 \x01(\x08\x12\x1b\n\x13spindle_ccw_visible\x18\x03 \x01(\x08\x12\x1c\n\x14spindle_stop_visible\x18\x04 \x01(\x08\x12\x1c\n\x14spindle_plus_visible\x18\x05 \x01(\x08\x12\x1d\n\x15spindle_minus_visible\x18\x06 \x01(\x08\x12 \n\x18spindle_override_visible\x18\x07 \x01(\x08\x12\x1d\n\x15\x63oolant_flood_visible\x18\x08 \x01(\x08\x12\x1c\n\x14\x63oolant_mist_visible\x18\t \x01(\x08:\x06\x92?\x03H\xdd\x08*\xe7\x02\n\x14\x45mcTaskExecStateType\x12\x17\n\x13\x45MC_TASK_EXEC_ERROR\x10\x01\x12\x16\n\x12\x45MC_TASK_EXEC_DONE\x10\x02\x12$\n EMC_TASK_EXEC_WAITING_FOR_MOTION\x10\x03\x12*\n&EMC_TASK_EXEC_WAITING_FOR_MOTION_QUEUE\x10\x04\x12 \n\x1c\x45MC_TASK_EXEC_WAITING_FOR_IO\x10\x05\x12+\n\'EMC_TASK_EXEC_WAITING_FOR_MOTION_AND_IO\x10\x07\x12#\n\x1f\x45MC_TASK_EXEC_WAITING_FOR_DELAY\x10\x08\x12(\n$EMC_TASK_EXEC_WAITING_FOR_SYSTEM_CMD\x10\t\x12.\n*EMC_TASK_EXEC_WAITING_FOR_SPINDLE_ORIENTED\x10\n*\x84\x01\n\x12\x45mcInterpStateType\x12\x18\n\x14\x45MC_TASK_INTERP_IDLE\x10\x01\x12\x1b\n\x17\x45MC_TASK_INTERP_READING\x10\x02\x12\x1a\n\x16\x45MC_TASK_INTERP_PAUSED\x10\x03\x12\x1b\n\x17\x45MC_TASK_INTERP_WAITING\x10\x04*\xc8\x01\n\x15\x45mcInterpExitCodeType\x12\x16\n\x12\x45MC_INTERP_EXIT_OK\x10\x00\x12\x18\n\x14\x45MC_INTERP_EXIT_EXIT\x10\x01\x12\"\n\x1e\x45MC_INTERP_EXIT_EXECUTE_FINISH\x10\x02\x12\x1b\n\x17\x45MC_INTERP_EXIT_ENDFILE\x10\x03\x12!\n\x1d\x45MC_INTERP_EXIT_FILE_NOT_OPEN\x10\x04\x12\x19\n\x15\x45MC_INTERP_EXIT_ERROR\x10\x05*{\n\x11\x45mcKinematicsType\x12\x17\n\x13KINEMATICS_IDENTITY\x10\x01\x12\x1b\n\x17KINEMATICS_FORWARD_ONLY\x10\x02\x12\x1b\n\x17KINEMATICS_INVERSE_ONLY\x10\x03\x12\x13\n\x0fKINEMATICS_BOTH\x10\x04*b\n\x15\x45mcTrajectoryModeType\x12\x16\n\x12\x45MC_TRAJ_MODE_FREE\x10\x01\x12\x17\n\x13\x45MC_TRAJ_MODE_COORD\x10\x02\x12\x18\n\x14\x45MC_TRAJ_MODE_TELEOP\x10\x03*Q\n\x11\x45mcCanonUnitsType\x12\x14\n\x10\x43\x41NON_UNITS_INCH\x10\x01\x12\x12\n\x0e\x43\x41NON_UNITS_MM\x10\x02\x12\x12\n\x0e\x43\x41NON_UNITS_CM\x10\x03*U\n\x12\x45mcLinearUnitsType\x12\x15\n\x11LINEAR_UNITS_INCH\x10\x01\x12\x13\n\x0fLINEAR_UNITS_MM\x10\x02\x12\x13\n\x0fLINEAR_UNITS_CM\x10\x03*b\n\x13\x45mcAngularUnitsType\x12\x19\n\x15\x41NGULAR_UNITS_DEGREES\x10\x01\x12\x18\n\x14\x41NGULAR_UNITS_RADIAN\x10\x02\x12\x16\n\x12\x41NGULAR_UNITS_GRAD\x10\x03*@\n\x10\x45mcTimeUnitsType\x12\x15\n\x11TIME_UNITS_MINUTE\x10\x01\x12\x15\n\x11TIME_UNITS_SECOND\x10\x02*Z\n\x0f\x45mcTaskModeType\x12\x18\n\x14\x45MC_TASK_MODE_MANUAL\x10\x01\x12\x16\n\x12\x45MC_TASK_MODE_AUTO\x10\x02\x12\x15\n\x11\x45MC_TASK_MODE_MDI\x10\x03*{\n\x10\x45mcTaskStateType\x12\x18\n\x14\x45MC_TASK_STATE_ESTOP\x10\x01\x12\x1e\n\x1a\x45MC_TASK_STATE_ESTOP_RESET\x10\x02\x12\x16\n\x12\x45MC_TASK_STATE_OFF\x10\x03\x12\x15\n\x11\x45MC_TASK_STATE_ON\x10\x04*8\n\x0b\x45mcAxisType\x12\x13\n\x0f\x45MC_AXIS_LINEAR\x10\x01\x12\x14\n\x10\x45MC_AXIS_ANGULAR\x10\x02*V\n\x15\x45mcPositionOffsetType\x12\x1e\n\x1a\x45MC_CONFIG_RELATIVE_OFFSET\x10\x01\x12\x1d\n\x19\x45MC_CONFIG_MACHINE_OFFSET\x10\x02*\\\n\x17\x45mcPositionFeedbackType\x12\x1e\n\x1a\x45MC_CONFIG_ACTUAL_FEEDBACK\x10\x01\x12!\n\x1d\x45MC_CONFIG_COMMANDED_FEEDBACK\x10\x02')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_preview__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_emcclass__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_motcmds__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EMCTASKEXECSTATETYPE = _descriptor.EnumDescriptor(
  name='EmcTaskExecStateType',
  full_name='machinetalk.EmcTaskExecStateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_ERROR', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_DONE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_WAITING_FOR_MOTION', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_WAITING_FOR_MOTION_QUEUE', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_WAITING_FOR_IO', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_WAITING_FOR_MOTION_AND_IO', index=5, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_WAITING_FOR_DELAY', index=6, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_WAITING_FOR_SYSTEM_CMD', index=7, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_EXEC_WAITING_FOR_SPINDLE_ORIENTED', index=8, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6005,
  serialized_end=6364,
)
_sym_db.RegisterEnumDescriptor(_EMCTASKEXECSTATETYPE)

EmcTaskExecStateType = enum_type_wrapper.EnumTypeWrapper(_EMCTASKEXECSTATETYPE)
_EMCINTERPSTATETYPE = _descriptor.EnumDescriptor(
  name='EmcInterpStateType',
  full_name='machinetalk.EmcInterpStateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_INTERP_IDLE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_INTERP_READING', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_INTERP_PAUSED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_INTERP_WAITING', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6367,
  serialized_end=6499,
)
_sym_db.RegisterEnumDescriptor(_EMCINTERPSTATETYPE)

EmcInterpStateType = enum_type_wrapper.EnumTypeWrapper(_EMCINTERPSTATETYPE)
_EMCINTERPEXITCODETYPE = _descriptor.EnumDescriptor(
  name='EmcInterpExitCodeType',
  full_name='machinetalk.EmcInterpExitCodeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_INTERP_EXIT_OK', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_INTERP_EXIT_EXIT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_INTERP_EXIT_EXECUTE_FINISH', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_INTERP_EXIT_ENDFILE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_INTERP_EXIT_FILE_NOT_OPEN', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_INTERP_EXIT_ERROR', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6502,
  serialized_end=6702,
)
_sym_db.RegisterEnumDescriptor(_EMCINTERPEXITCODETYPE)

EmcInterpExitCodeType = enum_type_wrapper.EnumTypeWrapper(_EMCINTERPEXITCODETYPE)
_EMCKINEMATICSTYPE = _descriptor.EnumDescriptor(
  name='EmcKinematicsType',
  full_name='machinetalk.EmcKinematicsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KINEMATICS_IDENTITY', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KINEMATICS_FORWARD_ONLY', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KINEMATICS_INVERSE_ONLY', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KINEMATICS_BOTH', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6704,
  serialized_end=6827,
)
_sym_db.RegisterEnumDescriptor(_EMCKINEMATICSTYPE)

EmcKinematicsType = enum_type_wrapper.EnumTypeWrapper(_EMCKINEMATICSTYPE)
_EMCTRAJECTORYMODETYPE = _descriptor.EnumDescriptor(
  name='EmcTrajectoryModeType',
  full_name='machinetalk.EmcTrajectoryModeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_TRAJ_MODE_FREE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TRAJ_MODE_COORD', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TRAJ_MODE_TELEOP', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6829,
  serialized_end=6927,
)
_sym_db.RegisterEnumDescriptor(_EMCTRAJECTORYMODETYPE)

EmcTrajectoryModeType = enum_type_wrapper.EnumTypeWrapper(_EMCTRAJECTORYMODETYPE)
_EMCCANONUNITSTYPE = _descriptor.EnumDescriptor(
  name='EmcCanonUnitsType',
  full_name='machinetalk.EmcCanonUnitsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CANON_UNITS_INCH', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANON_UNITS_MM', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANON_UNITS_CM', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6929,
  serialized_end=7010,
)
_sym_db.RegisterEnumDescriptor(_EMCCANONUNITSTYPE)

EmcCanonUnitsType = enum_type_wrapper.EnumTypeWrapper(_EMCCANONUNITSTYPE)
_EMCLINEARUNITSTYPE = _descriptor.EnumDescriptor(
  name='EmcLinearUnitsType',
  full_name='machinetalk.EmcLinearUnitsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LINEAR_UNITS_INCH', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINEAR_UNITS_MM', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINEAR_UNITS_CM', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7012,
  serialized_end=7097,
)
_sym_db.RegisterEnumDescriptor(_EMCLINEARUNITSTYPE)

EmcLinearUnitsType = enum_type_wrapper.EnumTypeWrapper(_EMCLINEARUNITSTYPE)
_EMCANGULARUNITSTYPE = _descriptor.EnumDescriptor(
  name='EmcAngularUnitsType',
  full_name='machinetalk.EmcAngularUnitsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANGULAR_UNITS_DEGREES', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANGULAR_UNITS_RADIAN', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANGULAR_UNITS_GRAD', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7099,
  serialized_end=7197,
)
_sym_db.RegisterEnumDescriptor(_EMCANGULARUNITSTYPE)

EmcAngularUnitsType = enum_type_wrapper.EnumTypeWrapper(_EMCANGULARUNITSTYPE)
_EMCTIMEUNITSTYPE = _descriptor.EnumDescriptor(
  name='EmcTimeUnitsType',
  full_name='machinetalk.EmcTimeUnitsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIME_UNITS_MINUTE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME_UNITS_SECOND', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7199,
  serialized_end=7263,
)
_sym_db.RegisterEnumDescriptor(_EMCTIMEUNITSTYPE)

EmcTimeUnitsType = enum_type_wrapper.EnumTypeWrapper(_EMCTIMEUNITSTYPE)
_EMCTASKMODETYPE = _descriptor.EnumDescriptor(
  name='EmcTaskModeType',
  full_name='machinetalk.EmcTaskModeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_MODE_MANUAL', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_MODE_AUTO', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_MODE_MDI', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7265,
  serialized_end=7355,
)
_sym_db.RegisterEnumDescriptor(_EMCTASKMODETYPE)

EmcTaskModeType = enum_type_wrapper.EnumTypeWrapper(_EMCTASKMODETYPE)
_EMCTASKSTATETYPE = _descriptor.EnumDescriptor(
  name='EmcTaskStateType',
  full_name='machinetalk.EmcTaskStateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_STATE_ESTOP', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_STATE_ESTOP_RESET', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_STATE_OFF', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_TASK_STATE_ON', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7357,
  serialized_end=7480,
)
_sym_db.RegisterEnumDescriptor(_EMCTASKSTATETYPE)

EmcTaskStateType = enum_type_wrapper.EnumTypeWrapper(_EMCTASKSTATETYPE)
_EMCAXISTYPE = _descriptor.EnumDescriptor(
  name='EmcAxisType',
  full_name='machinetalk.EmcAxisType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_AXIS_LINEAR', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_AXIS_ANGULAR', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7482,
  serialized_end=7538,
)
_sym_db.RegisterEnumDescriptor(_EMCAXISTYPE)

EmcAxisType = enum_type_wrapper.EnumTypeWrapper(_EMCAXISTYPE)
_EMCPOSITIONOFFSETTYPE = _descriptor.EnumDescriptor(
  name='EmcPositionOffsetType',
  full_name='machinetalk.EmcPositionOffsetType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_CONFIG_RELATIVE_OFFSET', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_CONFIG_MACHINE_OFFSET', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7540,
  serialized_end=7626,
)
_sym_db.RegisterEnumDescriptor(_EMCPOSITIONOFFSETTYPE)

EmcPositionOffsetType = enum_type_wrapper.EnumTypeWrapper(_EMCPOSITIONOFFSETTYPE)
_EMCPOSITIONFEEDBACKTYPE = _descriptor.EnumDescriptor(
  name='EmcPositionFeedbackType',
  full_name='machinetalk.EmcPositionFeedbackType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMC_CONFIG_ACTUAL_FEEDBACK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMC_CONFIG_COMMANDED_FEEDBACK', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7628,
  serialized_end=7720,
)
_sym_db.RegisterEnumDescriptor(_EMCPOSITIONFEEDBACKTYPE)

EmcPositionFeedbackType = enum_type_wrapper.EnumTypeWrapper(_EMCPOSITIONFEEDBACKTYPE)
EMC_TASK_EXEC_ERROR = 1
EMC_TASK_EXEC_DONE = 2
EMC_TASK_EXEC_WAITING_FOR_MOTION = 3
EMC_TASK_EXEC_WAITING_FOR_MOTION_QUEUE = 4
EMC_TASK_EXEC_WAITING_FOR_IO = 5
EMC_TASK_EXEC_WAITING_FOR_MOTION_AND_IO = 7
EMC_TASK_EXEC_WAITING_FOR_DELAY = 8
EMC_TASK_EXEC_WAITING_FOR_SYSTEM_CMD = 9
EMC_TASK_EXEC_WAITING_FOR_SPINDLE_ORIENTED = 10
EMC_TASK_INTERP_IDLE = 1
EMC_TASK_INTERP_READING = 2
EMC_TASK_INTERP_PAUSED = 3
EMC_TASK_INTERP_WAITING = 4
EMC_INTERP_EXIT_OK = 0
EMC_INTERP_EXIT_EXIT = 1
EMC_INTERP_EXIT_EXECUTE_FINISH = 2
EMC_INTERP_EXIT_ENDFILE = 3
EMC_INTERP_EXIT_FILE_NOT_OPEN = 4
EMC_INTERP_EXIT_ERROR = 5
KINEMATICS_IDENTITY = 1
KINEMATICS_FORWARD_ONLY = 2
KINEMATICS_INVERSE_ONLY = 3
KINEMATICS_BOTH = 4
EMC_TRAJ_MODE_FREE = 1
EMC_TRAJ_MODE_COORD = 2
EMC_TRAJ_MODE_TELEOP = 3
CANON_UNITS_INCH = 1
CANON_UNITS_MM = 2
CANON_UNITS_CM = 3
LINEAR_UNITS_INCH = 1
LINEAR_UNITS_MM = 2
LINEAR_UNITS_CM = 3
ANGULAR_UNITS_DEGREES = 1
ANGULAR_UNITS_RADIAN = 2
ANGULAR_UNITS_GRAD = 3
TIME_UNITS_MINUTE = 1
TIME_UNITS_SECOND = 2
EMC_TASK_MODE_MANUAL = 1
EMC_TASK_MODE_AUTO = 2
EMC_TASK_MODE_MDI = 3
EMC_TASK_STATE_ESTOP = 1
EMC_TASK_STATE_ESTOP_RESET = 2
EMC_TASK_STATE_OFF = 3
EMC_TASK_STATE_ON = 4
EMC_AXIS_LINEAR = 1
EMC_AXIS_ANGULAR = 2
EMC_CONFIG_RELATIVE_OFFSET = 1
EMC_CONFIG_MACHINE_OFFSET = 2
EMC_CONFIG_ACTUAL_FEEDBACK = 1
EMC_CONFIG_COMMANDED_FEEDBACK = 2



_EMCTOOLDATA = _descriptor.Descriptor(
  name='EmcToolData',
  full_name='machinetalk.EmcToolData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcToolData.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.EmcToolData.id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='diameter', full_name='machinetalk.EmcToolData.diameter', index=2,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frontangle', full_name='machinetalk.EmcToolData.frontangle', index=3,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='backangle', full_name='machinetalk.EmcToolData.backangle', index=4,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='machinetalk.EmcToolData.orientation', index=5,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='machinetalk.EmcToolData.offset', index=6,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='machinetalk.EmcToolData.comment', index=7,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pocket', full_name='machinetalk.EmcToolData.pocket', index=8,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\314\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=427,
)


_EMCSTATUSMOTIONAXIS = _descriptor.Descriptor(
  name='EmcStatusMotionAxis',
  full_name='machinetalk.EmcStatusMotionAxis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusMotionAxis.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='machinetalk.EmcStatusMotionAxis.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fault', full_name='machinetalk.EmcStatusMotionAxis.fault', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ferror_current', full_name='machinetalk.EmcStatusMotionAxis.ferror_current', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ferror_highmark', full_name='machinetalk.EmcStatusMotionAxis.ferror_highmark', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='homed', full_name='machinetalk.EmcStatusMotionAxis.homed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='homing', full_name='machinetalk.EmcStatusMotionAxis.homing', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inpos', full_name='machinetalk.EmcStatusMotionAxis.inpos', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input', full_name='machinetalk.EmcStatusMotionAxis.input', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_hard_limit', full_name='machinetalk.EmcStatusMotionAxis.max_hard_limit', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_soft_limit', full_name='machinetalk.EmcStatusMotionAxis.max_soft_limit', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_hard_limit', full_name='machinetalk.EmcStatusMotionAxis.min_hard_limit', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_soft_limit', full_name='machinetalk.EmcStatusMotionAxis.min_soft_limit', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='output', full_name='machinetalk.EmcStatusMotionAxis.output', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='override_limits', full_name='machinetalk.EmcStatusMotionAxis.override_limits', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='machinetalk.EmcStatusMotionAxis.velocity', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\315\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=771,
)


_EMCSTATUSCONFIGAXIS = _descriptor.Descriptor(
  name='EmcStatusConfigAxis',
  full_name='machinetalk.EmcStatusConfigAxis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusConfigAxis.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axis_type', full_name='machinetalk.EmcStatusConfigAxis.axis_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='backlash', full_name='machinetalk.EmcStatusConfigAxis.backlash', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_ferror', full_name='machinetalk.EmcStatusConfigAxis.max_ferror', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_position_limit', full_name='machinetalk.EmcStatusConfigAxis.max_position_limit', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_ferror', full_name='machinetalk.EmcStatusConfigAxis.min_ferror', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_position_limit', full_name='machinetalk.EmcStatusConfigAxis.min_position_limit', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='home_sequence', full_name='machinetalk.EmcStatusConfigAxis.home_sequence', index=7,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='machinetalk.EmcStatusConfigAxis.max_acceleration', index=8,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='machinetalk.EmcStatusConfigAxis.max_velocity', index=9,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='increments', full_name='machinetalk.EmcStatusConfigAxis.increments', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\316\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=1068,
)


_EMCPROGRAMEXTENSION = _descriptor.Descriptor(
  name='EmcProgramExtension',
  full_name='machinetalk.EmcProgramExtension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcProgramExtension.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extension', full_name='machinetalk.EmcProgramExtension.extension', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\317\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1070,
  serialized_end=1133,
)


_EMCSTATUSANALOGIO = _descriptor.Descriptor(
  name='EmcStatusAnalogIO',
  full_name='machinetalk.EmcStatusAnalogIO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusAnalogIO.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='machinetalk.EmcStatusAnalogIO.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\320\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1192,
)


_EMCSTATUSDIGITALIO = _descriptor.Descriptor(
  name='EmcStatusDigitalIO',
  full_name='machinetalk.EmcStatusDigitalIO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusDigitalIO.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='machinetalk.EmcStatusDigitalIO.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\321\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1252,
)


_EMCSTATUSLIMIT = _descriptor.Descriptor(
  name='EmcStatusLimit',
  full_name='machinetalk.EmcStatusLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusLimit.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='machinetalk.EmcStatusLimit.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\322\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1254,
  serialized_end=1308,
)


_EMCSTATUSGCODE = _descriptor.Descriptor(
  name='EmcStatusGCode',
  full_name='machinetalk.EmcStatusGCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusGCode.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='machinetalk.EmcStatusGCode.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\323\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1310,
  serialized_end=1364,
)


_EMCSTATUSMCODE = _descriptor.Descriptor(
  name='EmcStatusMCode',
  full_name='machinetalk.EmcStatusMCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusMCode.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='machinetalk.EmcStatusMCode.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\324\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1366,
  serialized_end=1420,
)


_EMCSTATUSSETTING = _descriptor.Descriptor(
  name='EmcStatusSetting',
  full_name='machinetalk.EmcStatusSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusSetting.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='machinetalk.EmcStatusSetting.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\325\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1422,
  serialized_end=1478,
)


_EMCSTATUSCONFIG = _descriptor.Descriptor(
  name='EmcStatusConfig',
  full_name='machinetalk.EmcStatusConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_acceleration', full_name='machinetalk.EmcStatusConfig.default_acceleration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axes', full_name='machinetalk.EmcStatusConfig.axes', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axis', full_name='machinetalk.EmcStatusConfig.axis', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axis_mask', full_name='machinetalk.EmcStatusConfig.axis_mask', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cycle_time', full_name='machinetalk.EmcStatusConfig.cycle_time', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug', full_name='machinetalk.EmcStatusConfig.debug', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kinematics_type', full_name='machinetalk.EmcStatusConfig.kinematics_type', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='machinetalk.EmcStatusConfig.max_acceleration', index=7,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='machinetalk.EmcStatusConfig.max_velocity', index=8,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='linear_units', full_name='machinetalk.EmcStatusConfig.linear_units', index=9,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='default_velocity', full_name='machinetalk.EmcStatusConfig.default_velocity', index=10,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='program_extension', full_name='machinetalk.EmcStatusConfig.program_extension', index=11,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position_offset', full_name='machinetalk.EmcStatusConfig.position_offset', index=12,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position_feedback', full_name='machinetalk.EmcStatusConfig.position_feedback', index=13,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_feed_override', full_name='machinetalk.EmcStatusConfig.max_feed_override', index=14,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_feed_override', full_name='machinetalk.EmcStatusConfig.min_feed_override', index=15,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_spindle_override', full_name='machinetalk.EmcStatusConfig.max_spindle_override', index=16,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_spindle_override', full_name='machinetalk.EmcStatusConfig.min_spindle_override', index=17,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='default_spindle_speed', full_name='machinetalk.EmcStatusConfig.default_spindle_speed', index=18,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='default_linear_velocity', full_name='machinetalk.EmcStatusConfig.default_linear_velocity', index=19,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_velocity', full_name='machinetalk.EmcStatusConfig.min_velocity', index=20,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_linear_velocity', full_name='machinetalk.EmcStatusConfig.max_linear_velocity', index=21,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_linear_velocity', full_name='machinetalk.EmcStatusConfig.min_linear_velocity', index=22,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='default_angular_velocity', full_name='machinetalk.EmcStatusConfig.default_angular_velocity', index=23,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_angular_velocity', full_name='machinetalk.EmcStatusConfig.max_angular_velocity', index=24,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_angular_velocity', full_name='machinetalk.EmcStatusConfig.min_angular_velocity', index=25,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='increments', full_name='machinetalk.EmcStatusConfig.increments', index=26,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='grids', full_name='machinetalk.EmcStatusConfig.grids', index=27,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lathe', full_name='machinetalk.EmcStatusConfig.lathe', index=28,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='machinetalk.EmcStatusConfig.geometry', index=29,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='arcdivision', full_name='machinetalk.EmcStatusConfig.arcdivision', index=30,
      number=33, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='no_force_homing', full_name='machinetalk.EmcStatusConfig.no_force_homing', index=31,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remote_path', full_name='machinetalk.EmcStatusConfig.remote_path', index=32,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_units', full_name='machinetalk.EmcStatusConfig.time_units', index=33,
      number=36, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.EmcStatusConfig.name', index=34,
      number=37, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_command', full_name='machinetalk.EmcStatusConfig.user_command', index=35,
      number=38, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular_units', full_name='machinetalk.EmcStatusConfig.angular_units', index=36,
      number=39, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\326\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1481,
  serialized_end=2691,
)


_EMCSTATUSMOTION = _descriptor.Descriptor(
  name='EmcStatusMotion',
  full_name='machinetalk.EmcStatusMotion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_queue', full_name='machinetalk.EmcStatusMotion.active_queue', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='actual_position', full_name='machinetalk.EmcStatusMotion.actual_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='adaptive_feed_enabled', full_name='machinetalk.EmcStatusMotion.adaptive_feed_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ain', full_name='machinetalk.EmcStatusMotion.ain', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aout', full_name='machinetalk.EmcStatusMotion.aout', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axis', full_name='machinetalk.EmcStatusMotion.axis', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='block_delete', full_name='machinetalk.EmcStatusMotion.block_delete', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_line', full_name='machinetalk.EmcStatusMotion.current_line', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_vel', full_name='machinetalk.EmcStatusMotion.current_vel', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delay_left', full_name='machinetalk.EmcStatusMotion.delay_left', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='din', full_name='machinetalk.EmcStatusMotion.din', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='distance_to_go', full_name='machinetalk.EmcStatusMotion.distance_to_go', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dout', full_name='machinetalk.EmcStatusMotion.dout', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dtg', full_name='machinetalk.EmcStatusMotion.dtg', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='machinetalk.EmcStatusMotion.enabled', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feed_hold_enabled', full_name='machinetalk.EmcStatusMotion.feed_hold_enabled', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feed_override_enabled', full_name='machinetalk.EmcStatusMotion.feed_override_enabled', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feedrate', full_name='machinetalk.EmcStatusMotion.feedrate', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g5x_index', full_name='machinetalk.EmcStatusMotion.g5x_index', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g5x_offset', full_name='machinetalk.EmcStatusMotion.g5x_offset', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g92_offset', full_name='machinetalk.EmcStatusMotion.g92_offset', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.EmcStatusMotion.id', index=21,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inpos', full_name='machinetalk.EmcStatusMotion.inpos', index=22,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='joint_actual_position', full_name='machinetalk.EmcStatusMotion.joint_actual_position', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='joint_position', full_name='machinetalk.EmcStatusMotion.joint_position', index=24,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limit', full_name='machinetalk.EmcStatusMotion.limit', index=25,
      number=27, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_line', full_name='machinetalk.EmcStatusMotion.motion_line', index=26,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_type', full_name='machinetalk.EmcStatusMotion.motion_type', index=27,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_mode', full_name='machinetalk.EmcStatusMotion.motion_mode', index=28,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='paused', full_name='machinetalk.EmcStatusMotion.paused', index=29,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='machinetalk.EmcStatusMotion.position', index=30,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probe_tripped', full_name='machinetalk.EmcStatusMotion.probe_tripped', index=31,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probe_val', full_name='machinetalk.EmcStatusMotion.probe_val', index=32,
      number=34, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probed_position', full_name='machinetalk.EmcStatusMotion.probed_position', index=33,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probing', full_name='machinetalk.EmcStatusMotion.probing', index=34,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queue', full_name='machinetalk.EmcStatusMotion.queue', index=35,
      number=37, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queue_full', full_name='machinetalk.EmcStatusMotion.queue_full', index=36,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation_xy', full_name='machinetalk.EmcStatusMotion.rotation_xy', index=37,
      number=39, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_brake', full_name='machinetalk.EmcStatusMotion.spindle_brake', index=38,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_direction', full_name='machinetalk.EmcStatusMotion.spindle_direction', index=39,
      number=41, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_enabled', full_name='machinetalk.EmcStatusMotion.spindle_enabled', index=40,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_increasing', full_name='machinetalk.EmcStatusMotion.spindle_increasing', index=41,
      number=43, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_override_enabled', full_name='machinetalk.EmcStatusMotion.spindle_override_enabled', index=42,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_speed', full_name='machinetalk.EmcStatusMotion.spindle_speed', index=43,
      number=45, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindlerate', full_name='machinetalk.EmcStatusMotion.spindlerate', index=44,
      number=46, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='machinetalk.EmcStatusMotion.state', index=45,
      number=47, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='machinetalk.EmcStatusMotion.max_velocity', index=46,
      number=48, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='machinetalk.EmcStatusMotion.max_acceleration', index=47,
      number=49, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rapidrate', full_name='machinetalk.EmcStatusMotion.rapidrate', index=48,
      number=50, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\327\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2694,
  serialized_end=4225,
)


_EMCSTATUSIO = _descriptor.Descriptor(
  name='EmcStatusIo',
  full_name='machinetalk.EmcStatusIo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='estop', full_name='machinetalk.EmcStatusIo.estop', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flood', full_name='machinetalk.EmcStatusIo.flood', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lube', full_name='machinetalk.EmcStatusIo.lube', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lube_level', full_name='machinetalk.EmcStatusIo.lube_level', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mist', full_name='machinetalk.EmcStatusIo.mist', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_offset', full_name='machinetalk.EmcStatusIo.tool_offset', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_table', full_name='machinetalk.EmcStatusIo.tool_table', index=6,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pocket_prepped', full_name='machinetalk.EmcStatusIo.pocket_prepped', index=7,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_in_spindle', full_name='machinetalk.EmcStatusIo.tool_in_spindle', index=8,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\330\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4228,
  serialized_end=4466,
)


_EMCSTATUSTASK = _descriptor.Descriptor(
  name='EmcStatusTask',
  full_name='machinetalk.EmcStatusTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='echo_serial_number', full_name='machinetalk.EmcStatusTask.echo_serial_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exec_state', full_name='machinetalk.EmcStatusTask.exec_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file', full_name='machinetalk.EmcStatusTask.file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_timeout', full_name='machinetalk.EmcStatusTask.input_timeout', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='optional_stop', full_name='machinetalk.EmcStatusTask.optional_stop', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_line', full_name='machinetalk.EmcStatusTask.read_line', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_mode', full_name='machinetalk.EmcStatusTask.task_mode', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_paused', full_name='machinetalk.EmcStatusTask.task_paused', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_state', full_name='machinetalk.EmcStatusTask.task_state', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_lines', full_name='machinetalk.EmcStatusTask.total_lines', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\331\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4469,
  serialized_end=4796,
)


_EMCSTATUSINTERP = _descriptor.Descriptor(
  name='EmcStatusInterp',
  full_name='machinetalk.EmcStatusInterp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='machinetalk.EmcStatusInterp.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gcodes', full_name='machinetalk.EmcStatusInterp.gcodes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interp_state', full_name='machinetalk.EmcStatusInterp.interp_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interpreter_errcode', full_name='machinetalk.EmcStatusInterp.interpreter_errcode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mcodes', full_name='machinetalk.EmcStatusInterp.mcodes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='settings', full_name='machinetalk.EmcStatusInterp.settings', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='program_units', full_name='machinetalk.EmcStatusInterp.program_units', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\332\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4799,
  serialized_end=5155,
)


_EMCCOMMANDPARAMETERS = _descriptor.Descriptor(
  name='EmcCommandParameters',
  full_name='machinetalk.EmcCommandParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcCommandParameters.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_level', full_name='machinetalk.EmcCommandParameters.debug_level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line_number', full_name='machinetalk.EmcCommandParameters.line_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scale', full_name='machinetalk.EmcCommandParameters.scale', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='machinetalk.EmcCommandParameters.velocity', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='distance', full_name='machinetalk.EmcCommandParameters.distance', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='machinetalk.EmcCommandParameters.value', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enable', full_name='machinetalk.EmcCommandParameters.enable', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='machinetalk.EmcCommandParameters.command', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='machinetalk.EmcCommandParameters.path', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_mode', full_name='machinetalk.EmcCommandParameters.task_mode', index=10,
      number=100, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_state', full_name='machinetalk.EmcCommandParameters.task_state', index=11,
      number=101, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traj_mode', full_name='machinetalk.EmcCommandParameters.traj_mode', index=12,
      number=102, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='machinetalk.EmcCommandParameters.pose', index=13,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_data', full_name='machinetalk.EmcCommandParameters.tool_data', index=14,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_table', full_name='machinetalk.EmcCommandParameters.tool_table', index=15,
      number=105, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\333\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5158,
  serialized_end=5640,
)


_EMCSTATUSUSERCOMMAND = _descriptor.Descriptor(
  name='EmcStatusUserCommand',
  full_name='machinetalk.EmcStatusUserCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.EmcStatusUserCommand.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='machinetalk.EmcStatusUserCommand.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\334\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5642,
  serialized_end=5704,
)


_EMCSTATUSUI = _descriptor.Descriptor(
  name='EmcStatusUI',
  full_name='machinetalk.EmcStatusUI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spindle_brake_visible', full_name='machinetalk.EmcStatusUI.spindle_brake_visible', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_cw_visible', full_name='machinetalk.EmcStatusUI.spindle_cw_visible', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_ccw_visible', full_name='machinetalk.EmcStatusUI.spindle_ccw_visible', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_stop_visible', full_name='machinetalk.EmcStatusUI.spindle_stop_visible', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_plus_visible', full_name='machinetalk.EmcStatusUI.spindle_plus_visible', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_minus_visible', full_name='machinetalk.EmcStatusUI.spindle_minus_visible', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spindle_override_visible', full_name='machinetalk.EmcStatusUI.spindle_override_visible', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coolant_flood_visible', full_name='machinetalk.EmcStatusUI.coolant_flood_visible', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coolant_mist_visible', full_name='machinetalk.EmcStatusUI.coolant_mist_visible', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\335\010')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5707,
  serialized_end=6002,
)

_EMCTOOLDATA.fields_by_name['offset'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSCONFIGAXIS.fields_by_name['axis_type'].enum_type = _EMCAXISTYPE
_EMCSTATUSCONFIG.fields_by_name['axis'].message_type = _EMCSTATUSCONFIGAXIS
_EMCSTATUSCONFIG.fields_by_name['kinematics_type'].enum_type = _EMCKINEMATICSTYPE
_EMCSTATUSCONFIG.fields_by_name['linear_units'].enum_type = _EMCLINEARUNITSTYPE
_EMCSTATUSCONFIG.fields_by_name['program_extension'].message_type = _EMCPROGRAMEXTENSION
_EMCSTATUSCONFIG.fields_by_name['position_offset'].enum_type = _EMCPOSITIONOFFSETTYPE
_EMCSTATUSCONFIG.fields_by_name['position_feedback'].enum_type = _EMCPOSITIONFEEDBACKTYPE
_EMCSTATUSCONFIG.fields_by_name['time_units'].enum_type = _EMCTIMEUNITSTYPE
_EMCSTATUSCONFIG.fields_by_name['user_command'].message_type = _EMCSTATUSUSERCOMMAND
_EMCSTATUSCONFIG.fields_by_name['angular_units'].enum_type = _EMCANGULARUNITSTYPE
_EMCSTATUSMOTION.fields_by_name['actual_position'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSMOTION.fields_by_name['ain'].message_type = _EMCSTATUSANALOGIO
_EMCSTATUSMOTION.fields_by_name['aout'].message_type = _EMCSTATUSANALOGIO
_EMCSTATUSMOTION.fields_by_name['axis'].message_type = _EMCSTATUSMOTIONAXIS
_EMCSTATUSMOTION.fields_by_name['din'].message_type = _EMCSTATUSDIGITALIO
_EMCSTATUSMOTION.fields_by_name['dout'].message_type = _EMCSTATUSDIGITALIO
_EMCSTATUSMOTION.fields_by_name['dtg'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSMOTION.fields_by_name['g5x_index'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._ORIGININDEX
_EMCSTATUSMOTION.fields_by_name['g5x_offset'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSMOTION.fields_by_name['g92_offset'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSMOTION.fields_by_name['joint_actual_position'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSMOTION.fields_by_name['joint_position'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSMOTION.fields_by_name['limit'].message_type = _EMCSTATUSLIMIT
_EMCSTATUSMOTION.fields_by_name['motion_type'].enum_type = machinetalk_dot_protobuf_dot_motcmds__pb2._MOTIONTYPE
_EMCSTATUSMOTION.fields_by_name['motion_mode'].enum_type = _EMCTRAJECTORYMODETYPE
_EMCSTATUSMOTION.fields_by_name['position'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSMOTION.fields_by_name['probed_position'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSMOTION.fields_by_name['state'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._RCS_STATUS
_EMCSTATUSIO.fields_by_name['tool_offset'].message_type = machinetalk_dot_protobuf_dot_preview__pb2._POSITION
_EMCSTATUSIO.fields_by_name['tool_table'].message_type = _EMCTOOLDATA
_EMCSTATUSTASK.fields_by_name['exec_state'].enum_type = _EMCTASKEXECSTATETYPE
_EMCSTATUSTASK.fields_by_name['task_mode'].enum_type = _EMCTASKMODETYPE
_EMCSTATUSTASK.fields_by_name['task_state'].enum_type = _EMCTASKSTATETYPE
_EMCSTATUSINTERP.fields_by_name['gcodes'].message_type = _EMCSTATUSGCODE
_EMCSTATUSINTERP.fields_by_name['interp_state'].enum_type = _EMCINTERPSTATETYPE
_EMCSTATUSINTERP.fields_by_name['interpreter_errcode'].enum_type = _EMCINTERPEXITCODETYPE
_EMCSTATUSINTERP.fields_by_name['mcodes'].message_type = _EMCSTATUSMCODE
_EMCSTATUSINTERP.fields_by_name['settings'].message_type = _EMCSTATUSSETTING
_EMCSTATUSINTERP.fields_by_name['program_units'].enum_type = _EMCCANONUNITSTYPE
_EMCCOMMANDPARAMETERS.fields_by_name['task_mode'].enum_type = _EMCTASKMODETYPE
_EMCCOMMANDPARAMETERS.fields_by_name['task_state'].enum_type = _EMCTASKSTATETYPE
_EMCCOMMANDPARAMETERS.fields_by_name['traj_mode'].enum_type = _EMCTRAJECTORYMODETYPE
_EMCCOMMANDPARAMETERS.fields_by_name['pose'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMCCOMMANDPARAMETERS.fields_by_name['tool_data'].message_type = _EMCTOOLDATA
_EMCCOMMANDPARAMETERS.fields_by_name['tool_table'].message_type = _EMCTOOLDATA
DESCRIPTOR.message_types_by_name['EmcToolData'] = _EMCTOOLDATA
DESCRIPTOR.message_types_by_name['EmcStatusMotionAxis'] = _EMCSTATUSMOTIONAXIS
DESCRIPTOR.message_types_by_name['EmcStatusConfigAxis'] = _EMCSTATUSCONFIGAXIS
DESCRIPTOR.message_types_by_name['EmcProgramExtension'] = _EMCPROGRAMEXTENSION
DESCRIPTOR.message_types_by_name['EmcStatusAnalogIO'] = _EMCSTATUSANALOGIO
DESCRIPTOR.message_types_by_name['EmcStatusDigitalIO'] = _EMCSTATUSDIGITALIO
DESCRIPTOR.message_types_by_name['EmcStatusLimit'] = _EMCSTATUSLIMIT
DESCRIPTOR.message_types_by_name['EmcStatusGCode'] = _EMCSTATUSGCODE
DESCRIPTOR.message_types_by_name['EmcStatusMCode'] = _EMCSTATUSMCODE
DESCRIPTOR.message_types_by_name['EmcStatusSetting'] = _EMCSTATUSSETTING
DESCRIPTOR.message_types_by_name['EmcStatusConfig'] = _EMCSTATUSCONFIG
DESCRIPTOR.message_types_by_name['EmcStatusMotion'] = _EMCSTATUSMOTION
DESCRIPTOR.message_types_by_name['EmcStatusIo'] = _EMCSTATUSIO
DESCRIPTOR.message_types_by_name['EmcStatusTask'] = _EMCSTATUSTASK
DESCRIPTOR.message_types_by_name['EmcStatusInterp'] = _EMCSTATUSINTERP
DESCRIPTOR.message_types_by_name['EmcCommandParameters'] = _EMCCOMMANDPARAMETERS
DESCRIPTOR.message_types_by_name['EmcStatusUserCommand'] = _EMCSTATUSUSERCOMMAND
DESCRIPTOR.message_types_by_name['EmcStatusUI'] = _EMCSTATUSUI
DESCRIPTOR.enum_types_by_name['EmcTaskExecStateType'] = _EMCTASKEXECSTATETYPE
DESCRIPTOR.enum_types_by_name['EmcInterpStateType'] = _EMCINTERPSTATETYPE
DESCRIPTOR.enum_types_by_name['EmcInterpExitCodeType'] = _EMCINTERPEXITCODETYPE
DESCRIPTOR.enum_types_by_name['EmcKinematicsType'] = _EMCKINEMATICSTYPE
DESCRIPTOR.enum_types_by_name['EmcTrajectoryModeType'] = _EMCTRAJECTORYMODETYPE
DESCRIPTOR.enum_types_by_name['EmcCanonUnitsType'] = _EMCCANONUNITSTYPE
DESCRIPTOR.enum_types_by_name['EmcLinearUnitsType'] = _EMCLINEARUNITSTYPE
DESCRIPTOR.enum_types_by_name['EmcAngularUnitsType'] = _EMCANGULARUNITSTYPE
DESCRIPTOR.enum_types_by_name['EmcTimeUnitsType'] = _EMCTIMEUNITSTYPE
DESCRIPTOR.enum_types_by_name['EmcTaskModeType'] = _EMCTASKMODETYPE
DESCRIPTOR.enum_types_by_name['EmcTaskStateType'] = _EMCTASKSTATETYPE
DESCRIPTOR.enum_types_by_name['EmcAxisType'] = _EMCAXISTYPE
DESCRIPTOR.enum_types_by_name['EmcPositionOffsetType'] = _EMCPOSITIONOFFSETTYPE
DESCRIPTOR.enum_types_by_name['EmcPositionFeedbackType'] = _EMCPOSITIONFEEDBACKTYPE

EmcToolData = _reflection.GeneratedProtocolMessageType('EmcToolData', (_message.Message,), dict(
  DESCRIPTOR = _EMCTOOLDATA,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcToolData)
  ))
_sym_db.RegisterMessage(EmcToolData)

EmcStatusMotionAxis = _reflection.GeneratedProtocolMessageType('EmcStatusMotionAxis', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSMOTIONAXIS,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusMotionAxis)
  ))
_sym_db.RegisterMessage(EmcStatusMotionAxis)

EmcStatusConfigAxis = _reflection.GeneratedProtocolMessageType('EmcStatusConfigAxis', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSCONFIGAXIS,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusConfigAxis)
  ))
_sym_db.RegisterMessage(EmcStatusConfigAxis)

EmcProgramExtension = _reflection.GeneratedProtocolMessageType('EmcProgramExtension', (_message.Message,), dict(
  DESCRIPTOR = _EMCPROGRAMEXTENSION,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcProgramExtension)
  ))
_sym_db.RegisterMessage(EmcProgramExtension)

EmcStatusAnalogIO = _reflection.GeneratedProtocolMessageType('EmcStatusAnalogIO', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSANALOGIO,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusAnalogIO)
  ))
_sym_db.RegisterMessage(EmcStatusAnalogIO)

EmcStatusDigitalIO = _reflection.GeneratedProtocolMessageType('EmcStatusDigitalIO', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSDIGITALIO,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusDigitalIO)
  ))
_sym_db.RegisterMessage(EmcStatusDigitalIO)

EmcStatusLimit = _reflection.GeneratedProtocolMessageType('EmcStatusLimit', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSLIMIT,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusLimit)
  ))
_sym_db.RegisterMessage(EmcStatusLimit)

EmcStatusGCode = _reflection.GeneratedProtocolMessageType('EmcStatusGCode', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSGCODE,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusGCode)
  ))
_sym_db.RegisterMessage(EmcStatusGCode)

EmcStatusMCode = _reflection.GeneratedProtocolMessageType('EmcStatusMCode', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSMCODE,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusMCode)
  ))
_sym_db.RegisterMessage(EmcStatusMCode)

EmcStatusSetting = _reflection.GeneratedProtocolMessageType('EmcStatusSetting', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSSETTING,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusSetting)
  ))
_sym_db.RegisterMessage(EmcStatusSetting)

EmcStatusConfig = _reflection.GeneratedProtocolMessageType('EmcStatusConfig', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSCONFIG,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusConfig)
  ))
_sym_db.RegisterMessage(EmcStatusConfig)

EmcStatusMotion = _reflection.GeneratedProtocolMessageType('EmcStatusMotion', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSMOTION,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusMotion)
  ))
_sym_db.RegisterMessage(EmcStatusMotion)

EmcStatusIo = _reflection.GeneratedProtocolMessageType('EmcStatusIo', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSIO,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusIo)
  ))
_sym_db.RegisterMessage(EmcStatusIo)

EmcStatusTask = _reflection.GeneratedProtocolMessageType('EmcStatusTask', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSTASK,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusTask)
  ))
_sym_db.RegisterMessage(EmcStatusTask)

EmcStatusInterp = _reflection.GeneratedProtocolMessageType('EmcStatusInterp', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSINTERP,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusInterp)
  ))
_sym_db.RegisterMessage(EmcStatusInterp)

EmcCommandParameters = _reflection.GeneratedProtocolMessageType('EmcCommandParameters', (_message.Message,), dict(
  DESCRIPTOR = _EMCCOMMANDPARAMETERS,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcCommandParameters)
  ))
_sym_db.RegisterMessage(EmcCommandParameters)

EmcStatusUserCommand = _reflection.GeneratedProtocolMessageType('EmcStatusUserCommand', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSUSERCOMMAND,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusUserCommand)
  ))
_sym_db.RegisterMessage(EmcStatusUserCommand)

EmcStatusUI = _reflection.GeneratedProtocolMessageType('EmcStatusUI', (_message.Message,), dict(
  DESCRIPTOR = _EMCSTATUSUI,
  __module__ = 'machinetalk.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcStatusUI)
  ))
_sym_db.RegisterMessage(EmcStatusUI)


_EMCTOOLDATA.has_options = True
_EMCTOOLDATA._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\314\010'))
_EMCSTATUSMOTIONAXIS.has_options = True
_EMCSTATUSMOTIONAXIS._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\315\010'))
_EMCSTATUSCONFIGAXIS.has_options = True
_EMCSTATUSCONFIGAXIS._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\316\010'))
_EMCPROGRAMEXTENSION.has_options = True
_EMCPROGRAMEXTENSION._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\317\010'))
_EMCSTATUSANALOGIO.has_options = True
_EMCSTATUSANALOGIO._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\320\010'))
_EMCSTATUSDIGITALIO.has_options = True
_EMCSTATUSDIGITALIO._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\321\010'))
_EMCSTATUSLIMIT.has_options = True
_EMCSTATUSLIMIT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\322\010'))
_EMCSTATUSGCODE.has_options = True
_EMCSTATUSGCODE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\323\010'))
_EMCSTATUSMCODE.has_options = True
_EMCSTATUSMCODE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\324\010'))
_EMCSTATUSSETTING.has_options = True
_EMCSTATUSSETTING._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\325\010'))
_EMCSTATUSCONFIG.has_options = True
_EMCSTATUSCONFIG._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\326\010'))
_EMCSTATUSMOTION.has_options = True
_EMCSTATUSMOTION._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\327\010'))
_EMCSTATUSIO.has_options = True
_EMCSTATUSIO._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\330\010'))
_EMCSTATUSTASK.has_options = True
_EMCSTATUSTASK._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\331\010'))
_EMCSTATUSINTERP.has_options = True
_EMCSTATUSINTERP._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\332\010'))
_EMCCOMMANDPARAMETERS.has_options = True
_EMCCOMMANDPARAMETERS._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\333\010'))
_EMCSTATUSUSERCOMMAND.has_options = True
_EMCSTATUSUSERCOMMAND._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\334\010'))
_EMCSTATUSUI.has_options = True
_EMCSTATUSUI._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\335\010'))
# @@protoc_insertion_point(module_scope)
