syntax = "proto2";
import "machinetalk/protobuf/nanopb.proto";
import "machinetalk/protobuf/value.proto";

// see README.msgid
// msgid base: 1000

package machinetalk;

message RTAPI_Message {

    option (nanopb_msgopt).msgid = 1000; // see README.msgid


    required int32 msglevel = 10; // [default = RTAPI_MSG_DBG];

    required string format     = 20 [default = "*** uninitialized ***",
                                     (nanopb).max_size = 100];

    // if this list of scalars is non-empty,
    // this implies sprintf(text, <arg>) should be applied
    // before display
    repeated Value arg = 30 [(nanopb).max_count = 10];
}
