# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/test.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import emcclass_pb2 as machinetalk_dot_protobuf_dot_emcclass__pb2
from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/test.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n\x1fmachinetalk/protobuf/test.proto\x12\x0bmachinetalk\x1a#machinetalk/protobuf/emcclass.proto\x1a!machinetalk/protobuf/nanopb.proto\"\xb9\x01\n\x05Test1\x12#\n\x02op\x18\n \x02(\x0e\x32\x17.machinetalk.TestOpType\x12!\n\x03\x65nd\x18\x14 \x02(\x0b\x32\x14.machinetalk.EmcPose\x12(\n\x06\x63\x65nter\x18\x1e \x01(\x0b\x32\x18.machinetalk.PmCartesian\x12(\n\x06normal\x18( \x01(\x0b\x32\x18.machinetalk.PmCartesian\x12\x0c\n\x04turn\x18\x32 \x01(\x05:\x06\x92?\x03H\x94\n\"\x0f\n\x05Test2:\x06\x92?\x03H\x95\n\"\x0f\n\x05Test3:\x06\x92?\x03H\x96\n*\"\n\nTestOpType\x12\x08\n\x04LINE\x10\n\x12\n\n\x06\x43IRCLE\x10\x14')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_emcclass__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_TESTOPTYPE = _descriptor.EnumDescriptor(
  name='TestOpType',
  full_name='machinetalk.TestOpType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LINE', index=0, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CIRCLE', index=1, number=20,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=342,
  serialized_end=376,
)
_sym_db.RegisterEnumDescriptor(_TESTOPTYPE)

TestOpType = enum_type_wrapper.EnumTypeWrapper(_TESTOPTYPE)
LINE = 10
CIRCLE = 20



_TEST1 = _descriptor.Descriptor(
  name='Test1',
  full_name='machinetalk.Test1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='machinetalk.Test1.op', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='machinetalk.Test1.end', index=1,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='center', full_name='machinetalk.Test1.center', index=2,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normal', full_name='machinetalk.Test1.normal', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='turn', full_name='machinetalk.Test1.turn', index=4,
      number=50, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\224\n')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=306,
)


_TEST2 = _descriptor.Descriptor(
  name='Test2',
  full_name='machinetalk.Test2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\225\n')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=323,
)


_TEST3 = _descriptor.Descriptor(
  name='Test3',
  full_name='machinetalk.Test3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\226\n')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=340,
)

_TEST1.fields_by_name['op'].enum_type = _TESTOPTYPE
_TEST1.fields_by_name['end'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_TEST1.fields_by_name['center'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._PMCARTESIAN
_TEST1.fields_by_name['normal'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._PMCARTESIAN
DESCRIPTOR.message_types_by_name['Test1'] = _TEST1
DESCRIPTOR.message_types_by_name['Test2'] = _TEST2
DESCRIPTOR.message_types_by_name['Test3'] = _TEST3
DESCRIPTOR.enum_types_by_name['TestOpType'] = _TESTOPTYPE

Test1 = _reflection.GeneratedProtocolMessageType('Test1', (_message.Message,), dict(
  DESCRIPTOR = _TEST1,
  __module__ = 'machinetalk.protobuf.test_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Test1)
  ))
_sym_db.RegisterMessage(Test1)

Test2 = _reflection.GeneratedProtocolMessageType('Test2', (_message.Message,), dict(
  DESCRIPTOR = _TEST2,
  __module__ = 'machinetalk.protobuf.test_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Test2)
  ))
_sym_db.RegisterMessage(Test2)

Test3 = _reflection.GeneratedProtocolMessageType('Test3', (_message.Message,), dict(
  DESCRIPTOR = _TEST3,
  __module__ = 'machinetalk.protobuf.test_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Test3)
  ))
_sym_db.RegisterMessage(Test3)


_TEST1.has_options = True
_TEST1._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\224\n'))
_TEST2.has_options = True
_TEST2._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\225\n'))
_TEST3.has_options = True
_TEST3._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\226\n'))
# @@protoc_insertion_point(module_scope)
