# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/value.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2
from machinetalk.protobuf import emcclass_pb2 as machinetalk_dot_protobuf_dot_emcclass__pb2
from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/value.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n machinetalk/protobuf/value.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\x1a#machinetalk/protobuf/emcclass.proto\x1a machinetalk/protobuf/types.proto\"\xdf\x02\n\x05Value\x12$\n\x04type\x18\n \x02(\x0e\x32\x16.machinetalk.ValueType\x12\x0e\n\x06halbit\x18\x64 \x01(\x08\x12\x10\n\x08halfloat\x18\x65 \x01(\x01\x12\x0e\n\x06hals32\x18\x66 \x01(\x0f\x12\x0e\n\x06halu32\x18g \x01(\x07\x12\x0f\n\x07v_bytes\x18x \x01(\x0c\x12\x10\n\x07v_int32\x18\x82\x01 \x01(\x0f\x12\x10\n\x07v_int64\x18\x8c\x01 \x01(\x10\x12\x11\n\x08v_uint32\x18\x96\x01 \x01(\x07\x12\x11\n\x08v_uint64\x18\xa0\x01 \x01(\x06\x12\x11\n\x08v_double\x18\xaa\x01 \x01(\x01\x12\x18\n\x08v_string\x18\xb4\x01 \x01(\tB\x05\x92?\x02\x08)\x12\x0f\n\x06v_bool\x18\xbe\x01 \x01(\x08\x12(\n\x05\x63\x61rte\x18\xc8\x01 \x01(\x0b\x32\x18.machinetalk.PmCartesian\x12#\n\x04pose\x18\xdc\x01 \x01(\x0b\x32\x14.machinetalk.EmcPose:\x06\x92?\x03H\xdc\x0b')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_emcclass__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='machinetalk.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Value.type', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halbit', full_name='machinetalk.Value.halbit', index=1,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halfloat', full_name='machinetalk.Value.halfloat', index=2,
      number=101, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hals32', full_name='machinetalk.Value.hals32', index=3,
      number=102, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halu32', full_name='machinetalk.Value.halu32', index=4,
      number=103, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v_bytes', full_name='machinetalk.Value.v_bytes', index=5,
      number=120, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v_int32', full_name='machinetalk.Value.v_int32', index=6,
      number=130, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v_int64', full_name='machinetalk.Value.v_int64', index=7,
      number=140, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v_uint32', full_name='machinetalk.Value.v_uint32', index=8,
      number=150, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v_uint64', full_name='machinetalk.Value.v_uint64', index=9,
      number=160, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v_double', full_name='machinetalk.Value.v_double', index=10,
      number=170, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v_string', full_name='machinetalk.Value.v_string', index=11,
      number=180, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\010)'))),
    _descriptor.FieldDescriptor(
      name='v_bool', full_name='machinetalk.Value.v_bool', index=12,
      number=190, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='carte', full_name='machinetalk.Value.carte', index=13,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='machinetalk.Value.pose', index=14,
      number=220, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\334\013')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=507,
)

_VALUE.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._VALUETYPE
_VALUE.fields_by_name['carte'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._PMCARTESIAN
_VALUE.fields_by_name['pose'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
DESCRIPTOR.message_types_by_name['Value'] = _VALUE

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
  DESCRIPTOR = _VALUE,
  __module__ = 'machinetalk.protobuf.value_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Value)
  ))
_sym_db.RegisterMessage(Value)


_VALUE.fields_by_name['v_string'].has_options = True
_VALUE.fields_by_name['v_string']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\010)'))
_VALUE.has_options = True
_VALUE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\334\013'))
# @@protoc_insertion_point(module_scope)
