# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/object.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2
from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/object.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n!machinetalk/protobuf/object.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\x1a machinetalk/protobuf/types.proto\",\n\x08Instance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x0f:\x06\x92?\x03H\xbc\x05\"\xb7\x01\n\x13ServiceAnnouncement\x12\'\n\x05stype\x18\x01 \x02(\x0e\x32\x18.machinetalk.ServiceType\x12\x12\n\x07version\x18\x02 \x02(\x07:\x01\x30\x12\x13\n\x08instance\x18\x03 \x02(\x07:\x01\x30\x12$\n\x03\x61pi\x18\x08 \x02(\x0e\x32\x17.machinetalk.ServiceAPI\x12\x0b\n\x03uri\x18\x06 \x02(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t:\x06\x92?\x03H\xbd\x05\"\xab\x01\n\nOriginator\x12\'\n\x06origin\x18\x01 \x01(\x0e\x32\x17.machinetalk.OriginType\x12)\n\x06\x64\x65tail\x18\x02 \x01(\x0e\x32\x19.machinetalk.OriginDetail\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\x0f\x12\'\n\x08instance\x18\x05 \x01(\x0b\x32\x15.machinetalk.Instance:\x06\x92?\x03H\xbe\x05\"\x8b\x01\n\x07\x41nError\x12\x12\n\nerror_code\x18\x01 \x02(\x0f\x12\'\n\x08severity\x18\x02 \x01(\x0e\x32\x15.machinetalk.Severity\x12\x12\n\nerror_text\x18\x03 \x01(\t\x12\'\n\x06origin\x18\x04 \x01(\x0b\x32\x17.machinetalk.Originator:\x06\x92?\x03H\xbf\x05\"\x8e\x02\n\x03Pin\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.machinetalk.ValueType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\x07\x12)\n\x03\x64ir\x18\x04 \x01(\x0e\x32\x1c.machinetalk.HalPinDirection\x12\x0e\n\x06halbit\x18\x05 \x01(\x08\x12\x10\n\x08halfloat\x18\x06 \x01(\x01\x12\x0e\n\x06hals32\x18\x07 \x01(\x0f\x12\x0e\n\x06halu32\x18\x08 \x01(\x07\x12\r\n\x05owner\x18\t \x01(\x0f\x12\x0e\n\x06linked\x18\n \x01(\x08\x12\x0f\n\x07oldname\x18\x0b \x01(\t\x12\x0f\n\x07\x65psilon\x18\x0c \x01(\x01\x12\r\n\x05\x66lags\x18\r \x01(\x07:\x06\x92?\x03H\xc0\x05\"\xe6\x01\n\x06Signal\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.machinetalk.ValueType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\x07\x12\x0e\n\x06halbit\x18\x05 \x01(\x08\x12\x10\n\x08halfloat\x18\x06 \x01(\x01\x12\x0e\n\x06hals32\x18\x07 \x01(\x0f\x12\x0e\n\x06halu32\x18\x08 \x01(\x07\x12\x0e\n\x06strval\x18\t \x01(\t\x12\x0c\n\x04\x62lob\x18\n \x01(\x0c\x12\x0f\n\x07readers\x18\x0b \x01(\x07\x12\x0f\n\x07writers\x18\x0c \x01(\x07\x12\x0e\n\x06\x62idirs\x18\r \x01(\x07:\x06\x92?\x03H\xc1\x05\"\xa2\x02\n\x05Param\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.machinetalk.ValueType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\x07\x12\x0e\n\x06halbit\x18\x05 \x01(\x08\x12\x10\n\x08halfloat\x18\x06 \x01(\x01\x12\x0e\n\x06hals32\x18\x07 \x01(\x0f\x12\x0e\n\x06halu32\x18\x08 \x01(\x07\x12\x0e\n\x06strval\x18\t \x01(\t\x12\x0c\n\x04\x62lob\x18\n \x01(\x0c\x12+\n\x03\x64ir\x18\x0b \x01(\x0e\x32\x1e.machinetalk.HalParamDirection\x12\x0f\n\x07oldname\x18\x0c \x01(\t\x12\r\n\x05owner\x18\r \x01(\x0f\x12\x0f\n\x07runtime\x18\x0e \x01(\x0f\x12\x0f\n\x07maytime\x18\x0f \x01(\x0f:\x06\x92?\x03H\xc2\x05\"\xca\x01\n\x08\x46unction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\x10\n\x08owner_id\x18\x03 \x01(\x07\x12\r\n\x05users\x18\x04 \x01(\x07\x12\x0f\n\x07runtime\x18\x05 \x01(\x07\x12\x0f\n\x07maxtime\x18\x06 \x01(\x07\x12\x11\n\treentrant\x18\x07 \x01(\x08\x12\'\n\x04type\x18\x08 \x01(\x0e\x32\x19.machinetalk.HalFunctType\x12\x19\n\x11maxtime_increased\x18\t \x01(\x08:\x06\x92?\x03H\xc3\x05\"\x94\x01\n\x06Thread\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\x0f\n\x07uses_fp\x18\x03 \x01(\x08\x12\x0e\n\x06period\x18\x04 \x01(\x07\x12\x10\n\x08priority\x18\x05 \x01(\x0f\x12\x0f\n\x07task_id\x18\x06 \x01(\x07\x12\x0e\n\x06\x63pu_id\x18\x07 \x01(\x07\x12\x10\n\x08\x66unction\x18\x08 \x03(\t:\x06\x92?\x03H\xc4\x05\"\xe6\x02\n\tComponent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05ninst\x18\x02 \x01(\x07\x12\x0f\n\x07\x63omp_id\x18\x04 \x01(\x0f\x12\x0c\n\x04type\x18\x05 \x01(\x07\x12\r\n\x05state\x18\x06 \x01(\x07\x12\x13\n\x0blast_update\x18\x07 \x01(\x07\x12\x12\n\nlast_bound\x18\x08 \x01(\x07\x12\x14\n\x0clast_unbound\x18\t \x01(\x07\x12\x0b\n\x03pid\x18\n \x01(\x07\x12\x0c\n\x04\x61rgs\x18\x0b \x01(\t\x12\r\n\x05timer\x18\x0c \x01(\x0f\x12\x10\n\x08userarg1\x18\x0e \x01(\x0f\x12\x10\n\x08userarg2\x18\x0f \x01(\x0f\x12\x1d\n\x03pin\x18\x10 \x03(\x0b\x32\x10.machinetalk.Pin\x12!\n\x05param\x18\x11 \x03(\x0b\x32\x12.machinetalk.Param\x12$\n\x05\x66unct\x18\x13 \x03(\x0b\x32\x15.machinetalk.Function\x12\x11\n\tno_create\x18\x12 \x01(\x08:\x06\x92?\x03H\xc5\x05\"\xee\x01\n\x04Ring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\r\n\x05owner\x18\x03 \x01(\x0f\x12\x0e\n\x06stream\x18\x04 \x01(\x08\x12\x0e\n\x06wmutex\x18\x05 \x01(\x08\x12\x0e\n\x06rmutex\x18\x06 \x01(\x08\x12\x11\n\trtapi_shm\x18\x07 \x01(\x08\x12\x0e\n\x06reader\x18\x08 \x01(\x0f\x12\x0e\n\x06writer\x18\t \x01(\x0f\x12\x12\n\ntotal_size\x18\n \x01(\x0f\x12\x12\n\nscratchpad\x18\x0b \x01(\x0f\x12\x13\n\x0bring_shmkey\x18\x0c \x01(\x0f\x12\x11\n\tencodings\x18\r \x01(\x07:\x06\x92?\x03H\xc6\x05\"\xe5\x01\n\x06Member\x12&\n\x05mtype\x18\x01 \x01(\x0e\x32\x17.machinetalk.ObjectType\x12\x10\n\x08userarg1\x18\x02 \x01(\x0f\x12\x0f\n\x07\x65psilon\x18\x03 \x01(\x01\x12#\n\x06signal\x18\x04 \x01(\x0b\x32\x13.machinetalk.Signal\x12\x11\n\tgroupname\x18\x05 \x01(\t\x12\x0e\n\x06handle\x18\x06 \x01(\x07\x12\x1d\n\x03pin\x18\x07 \x01(\x0b\x32\x10.machinetalk.Pin\x12!\n\x05param\x18\x08 \x01(\x0b\x32\x12.machinetalk.Param:\x06\x92?\x03H\xc7\x05\"\x88\x01\n\x05Group\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\x10\n\x08userarg1\x18\x04 \x01(\x0f\x12\x10\n\x08userarg2\x18\x05 \x01(\x0f\x12\x10\n\x08refcount\x18\x06 \x01(\x0f\x12#\n\x06member\x18\x07 \x03(\x0b\x32\x13.machinetalk.Member:\x06\x92?\x03H\xc8\x05\"_\n\x12ProtocolParameters\x12\x17\n\x0fkeepalive_timer\x18\x01 \x01(\x0f\x12\x13\n\x0bgroup_timer\x18\x02 \x01(\x0f\x12\x13\n\x0brcomp_timer\x18\x03 \x01(\x0f:\x06\x92?\x03H\xc9\x05\"\x84\x01\n\x06Vtable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\x10\n\x08owner_id\x18\x03 \x01(\x0f\x12\x0f\n\x07\x63ontext\x18\x05 \x01(\x07\x12\x10\n\x08refcount\x18\x06 \x01(\x0f\x12\x0f\n\x07version\x18\x07 \x01(\x0f\x12\x0e\n\x06vtable\x18\x08 \x01(\x06:\x06\x92?\x03H\xca\x05\"\xc9\x01\n\x04Inst\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63omp_id\x18\x02 \x01(\x0f\x12\x0f\n\x07inst_id\x18\x03 \x01(\x07\x12\x11\n\tinst_size\x18\x04 \x01(\x07\x12\x0e\n\x06vtable\x18\x05 \x01(\x06\x12\x1d\n\x03pin\x18\x10 \x03(\x0b\x32\x10.machinetalk.Pin\x12!\n\x05param\x18\x11 \x03(\x0b\x32\x12.machinetalk.Param\x12$\n\x05\x66unct\x18\x13 \x03(\x0b\x32\x15.machinetalk.Function:\x06\x92?\x03H\xcb\x05')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_INSTANCE = _descriptor.Descriptor(
  name='Instance',
  full_name='machinetalk.Instance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Instance.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.Instance.id', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\274\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=163,
)


_SERVICEANNOUNCEMENT = _descriptor.Descriptor(
  name='ServiceAnnouncement',
  full_name='machinetalk.ServiceAnnouncement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stype', full_name='machinetalk.ServiceAnnouncement.stype', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='machinetalk.ServiceAnnouncement.version', index=1,
      number=2, type=7, cpp_type=3, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instance', full_name='machinetalk.ServiceAnnouncement.instance', index=2,
      number=3, type=7, cpp_type=3, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api', full_name='machinetalk.ServiceAnnouncement.api', index=3,
      number=8, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uri', full_name='machinetalk.ServiceAnnouncement.uri', index=4,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='machinetalk.ServiceAnnouncement.description', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\275\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=349,
)


_ORIGINATOR = _descriptor.Descriptor(
  name='Originator',
  full_name='machinetalk.Originator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='machinetalk.Originator.origin', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='detail', full_name='machinetalk.Originator.detail', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Originator.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.Originator.id', index=3,
      number=4, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instance', full_name='machinetalk.Originator.instance', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\276\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=523,
)


_ANERROR = _descriptor.Descriptor(
  name='AnError',
  full_name='machinetalk.AnError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='machinetalk.AnError.error_code', index=0,
      number=1, type=15, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='severity', full_name='machinetalk.AnError.severity', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_text', full_name='machinetalk.AnError.error_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='machinetalk.AnError.origin', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\277\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=665,
)


_PIN = _descriptor.Descriptor(
  name='Pin',
  full_name='machinetalk.Pin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Pin.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Pin.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Pin.handle', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dir', full_name='machinetalk.Pin.dir', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=16,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halbit', full_name='machinetalk.Pin.halbit', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halfloat', full_name='machinetalk.Pin.halfloat', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hals32', full_name='machinetalk.Pin.hals32', index=6,
      number=7, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halu32', full_name='machinetalk.Pin.halu32', index=7,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner', full_name='machinetalk.Pin.owner', index=8,
      number=9, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='linked', full_name='machinetalk.Pin.linked', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='oldname', full_name='machinetalk.Pin.oldname', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='machinetalk.Pin.epsilon', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='machinetalk.Pin.flags', index=12,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\300\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=938,
)


_SIGNAL = _descriptor.Descriptor(
  name='Signal',
  full_name='machinetalk.Signal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Signal.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Signal.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Signal.handle', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halbit', full_name='machinetalk.Signal.halbit', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halfloat', full_name='machinetalk.Signal.halfloat', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hals32', full_name='machinetalk.Signal.hals32', index=5,
      number=7, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halu32', full_name='machinetalk.Signal.halu32', index=6,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strval', full_name='machinetalk.Signal.strval', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blob', full_name='machinetalk.Signal.blob', index=8,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='readers', full_name='machinetalk.Signal.readers', index=9,
      number=11, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='writers', full_name='machinetalk.Signal.writers', index=10,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bidirs', full_name='machinetalk.Signal.bidirs', index=11,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\301\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=941,
  serialized_end=1171,
)


_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='machinetalk.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Param.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Param.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Param.handle', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halbit', full_name='machinetalk.Param.halbit', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halfloat', full_name='machinetalk.Param.halfloat', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hals32', full_name='machinetalk.Param.hals32', index=5,
      number=7, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halu32', full_name='machinetalk.Param.halu32', index=6,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strval', full_name='machinetalk.Param.strval', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blob', full_name='machinetalk.Param.blob', index=8,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dir', full_name='machinetalk.Param.dir', index=9,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=64,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='oldname', full_name='machinetalk.Param.oldname', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner', full_name='machinetalk.Param.owner', index=11,
      number=13, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='machinetalk.Param.runtime', index=12,
      number=14, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maytime', full_name='machinetalk.Param.maytime', index=13,
      number=15, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\302\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1464,
)


_FUNCTION = _descriptor.Descriptor(
  name='Function',
  full_name='machinetalk.Function',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Function.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Function.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='machinetalk.Function.owner_id', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='users', full_name='machinetalk.Function.users', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='machinetalk.Function.runtime', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxtime', full_name='machinetalk.Function.maxtime', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reentrant', full_name='machinetalk.Function.reentrant', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Function.type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxtime_increased', full_name='machinetalk.Function.maxtime_increased', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\303\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1669,
)


_THREAD = _descriptor.Descriptor(
  name='Thread',
  full_name='machinetalk.Thread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Thread.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Thread.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uses_fp', full_name='machinetalk.Thread.uses_fp', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='period', full_name='machinetalk.Thread.period', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priority', full_name='machinetalk.Thread.priority', index=4,
      number=5, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='machinetalk.Thread.task_id', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_id', full_name='machinetalk.Thread.cpu_id', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='function', full_name='machinetalk.Thread.function', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\304\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1672,
  serialized_end=1820,
)


_COMPONENT = _descriptor.Descriptor(
  name='Component',
  full_name='machinetalk.Component',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Component.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ninst', full_name='machinetalk.Component.ninst', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comp_id', full_name='machinetalk.Component.comp_id', index=2,
      number=4, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Component.type', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='machinetalk.Component.state', index=4,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_update', full_name='machinetalk.Component.last_update', index=5,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_bound', full_name='machinetalk.Component.last_bound', index=6,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_unbound', full_name='machinetalk.Component.last_unbound', index=7,
      number=9, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pid', full_name='machinetalk.Component.pid', index=8,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='args', full_name='machinetalk.Component.args', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timer', full_name='machinetalk.Component.timer', index=10,
      number=12, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg1', full_name='machinetalk.Component.userarg1', index=11,
      number=14, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg2', full_name='machinetalk.Component.userarg2', index=12,
      number=15, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin', full_name='machinetalk.Component.pin', index=13,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param', full_name='machinetalk.Component.param', index=14,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='funct', full_name='machinetalk.Component.funct', index=15,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='no_create', full_name='machinetalk.Component.no_create', index=16,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\305\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1823,
  serialized_end=2181,
)


_RING = _descriptor.Descriptor(
  name='Ring',
  full_name='machinetalk.Ring',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Ring.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Ring.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner', full_name='machinetalk.Ring.owner', index=2,
      number=3, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stream', full_name='machinetalk.Ring.stream', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wmutex', full_name='machinetalk.Ring.wmutex', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rmutex', full_name='machinetalk.Ring.rmutex', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rtapi_shm', full_name='machinetalk.Ring.rtapi_shm', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reader', full_name='machinetalk.Ring.reader', index=7,
      number=8, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='writer', full_name='machinetalk.Ring.writer', index=8,
      number=9, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='machinetalk.Ring.total_size', index=9,
      number=10, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scratchpad', full_name='machinetalk.Ring.scratchpad', index=10,
      number=11, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ring_shmkey', full_name='machinetalk.Ring.ring_shmkey', index=11,
      number=12, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encodings', full_name='machinetalk.Ring.encodings', index=12,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\306\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2184,
  serialized_end=2422,
)


_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='machinetalk.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mtype', full_name='machinetalk.Member.mtype', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg1', full_name='machinetalk.Member.userarg1', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='machinetalk.Member.epsilon', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='machinetalk.Member.signal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='groupname', full_name='machinetalk.Member.groupname', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Member.handle', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin', full_name='machinetalk.Member.pin', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param', full_name='machinetalk.Member.param', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\307\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2425,
  serialized_end=2654,
)


_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='machinetalk.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Group.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Group.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg1', full_name='machinetalk.Group.userarg1', index=2,
      number=4, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg2', full_name='machinetalk.Group.userarg2', index=3,
      number=5, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='refcount', full_name='machinetalk.Group.refcount', index=4,
      number=6, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='machinetalk.Group.member', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\310\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2657,
  serialized_end=2793,
)


_PROTOCOLPARAMETERS = _descriptor.Descriptor(
  name='ProtocolParameters',
  full_name='machinetalk.ProtocolParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keepalive_timer', full_name='machinetalk.ProtocolParameters.keepalive_timer', index=0,
      number=1, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_timer', full_name='machinetalk.ProtocolParameters.group_timer', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rcomp_timer', full_name='machinetalk.ProtocolParameters.rcomp_timer', index=2,
      number=3, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\311\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2795,
  serialized_end=2890,
)


_VTABLE = _descriptor.Descriptor(
  name='Vtable',
  full_name='machinetalk.Vtable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Vtable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Vtable.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='machinetalk.Vtable.owner_id', index=2,
      number=3, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='context', full_name='machinetalk.Vtable.context', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='refcount', full_name='machinetalk.Vtable.refcount', index=4,
      number=6, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='machinetalk.Vtable.version', index=5,
      number=7, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vtable', full_name='machinetalk.Vtable.vtable', index=6,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\312\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2893,
  serialized_end=3025,
)


_INST = _descriptor.Descriptor(
  name='Inst',
  full_name='machinetalk.Inst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Inst.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comp_id', full_name='machinetalk.Inst.comp_id', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inst_id', full_name='machinetalk.Inst.inst_id', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inst_size', full_name='machinetalk.Inst.inst_size', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vtable', full_name='machinetalk.Inst.vtable', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin', full_name='machinetalk.Inst.pin', index=5,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param', full_name='machinetalk.Inst.param', index=6,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='funct', full_name='machinetalk.Inst.funct', index=7,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\313\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3028,
  serialized_end=3229,
)

_SERVICEANNOUNCEMENT.fields_by_name['stype'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._SERVICETYPE
_SERVICEANNOUNCEMENT.fields_by_name['api'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._SERVICEAPI
_ORIGINATOR.fields_by_name['origin'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._ORIGINTYPE
_ORIGINATOR.fields_by_name['detail'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._ORIGINDETAIL
_ORIGINATOR.fields_by_name['instance'].message_type = _INSTANCE
_ANERROR.fields_by_name['severity'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._SEVERITY
_ANERROR.fields_by_name['origin'].message_type = _ORIGINATOR
_PIN.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._VALUETYPE
_PIN.fields_by_name['dir'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._HALPINDIRECTION
_SIGNAL.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._VALUETYPE
_PARAM.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._VALUETYPE
_PARAM.fields_by_name['dir'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._HALPARAMDIRECTION
_FUNCTION.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._HALFUNCTTYPE
_COMPONENT.fields_by_name['pin'].message_type = _PIN
_COMPONENT.fields_by_name['param'].message_type = _PARAM
_COMPONENT.fields_by_name['funct'].message_type = _FUNCTION
_MEMBER.fields_by_name['mtype'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._OBJECTTYPE
_MEMBER.fields_by_name['signal'].message_type = _SIGNAL
_MEMBER.fields_by_name['pin'].message_type = _PIN
_MEMBER.fields_by_name['param'].message_type = _PARAM
_GROUP.fields_by_name['member'].message_type = _MEMBER
_INST.fields_by_name['pin'].message_type = _PIN
_INST.fields_by_name['param'].message_type = _PARAM
_INST.fields_by_name['funct'].message_type = _FUNCTION
DESCRIPTOR.message_types_by_name['Instance'] = _INSTANCE
DESCRIPTOR.message_types_by_name['ServiceAnnouncement'] = _SERVICEANNOUNCEMENT
DESCRIPTOR.message_types_by_name['Originator'] = _ORIGINATOR
DESCRIPTOR.message_types_by_name['AnError'] = _ANERROR
DESCRIPTOR.message_types_by_name['Pin'] = _PIN
DESCRIPTOR.message_types_by_name['Signal'] = _SIGNAL
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['Function'] = _FUNCTION
DESCRIPTOR.message_types_by_name['Thread'] = _THREAD
DESCRIPTOR.message_types_by_name['Component'] = _COMPONENT
DESCRIPTOR.message_types_by_name['Ring'] = _RING
DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
DESCRIPTOR.message_types_by_name['Group'] = _GROUP
DESCRIPTOR.message_types_by_name['ProtocolParameters'] = _PROTOCOLPARAMETERS
DESCRIPTOR.message_types_by_name['Vtable'] = _VTABLE
DESCRIPTOR.message_types_by_name['Inst'] = _INST

Instance = _reflection.GeneratedProtocolMessageType('Instance', (_message.Message,), dict(
  DESCRIPTOR = _INSTANCE,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Instance)
  ))
_sym_db.RegisterMessage(Instance)

ServiceAnnouncement = _reflection.GeneratedProtocolMessageType('ServiceAnnouncement', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEANNOUNCEMENT,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.ServiceAnnouncement)
  ))
_sym_db.RegisterMessage(ServiceAnnouncement)

Originator = _reflection.GeneratedProtocolMessageType('Originator', (_message.Message,), dict(
  DESCRIPTOR = _ORIGINATOR,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Originator)
  ))
_sym_db.RegisterMessage(Originator)

AnError = _reflection.GeneratedProtocolMessageType('AnError', (_message.Message,), dict(
  DESCRIPTOR = _ANERROR,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.AnError)
  ))
_sym_db.RegisterMessage(AnError)

Pin = _reflection.GeneratedProtocolMessageType('Pin', (_message.Message,), dict(
  DESCRIPTOR = _PIN,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Pin)
  ))
_sym_db.RegisterMessage(Pin)

Signal = _reflection.GeneratedProtocolMessageType('Signal', (_message.Message,), dict(
  DESCRIPTOR = _SIGNAL,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Signal)
  ))
_sym_db.RegisterMessage(Signal)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), dict(
  DESCRIPTOR = _PARAM,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Param)
  ))
_sym_db.RegisterMessage(Param)

Function = _reflection.GeneratedProtocolMessageType('Function', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTION,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Function)
  ))
_sym_db.RegisterMessage(Function)

Thread = _reflection.GeneratedProtocolMessageType('Thread', (_message.Message,), dict(
  DESCRIPTOR = _THREAD,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Thread)
  ))
_sym_db.RegisterMessage(Thread)

Component = _reflection.GeneratedProtocolMessageType('Component', (_message.Message,), dict(
  DESCRIPTOR = _COMPONENT,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Component)
  ))
_sym_db.RegisterMessage(Component)

Ring = _reflection.GeneratedProtocolMessageType('Ring', (_message.Message,), dict(
  DESCRIPTOR = _RING,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Ring)
  ))
_sym_db.RegisterMessage(Ring)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
  DESCRIPTOR = _MEMBER,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Member)
  ))
_sym_db.RegisterMessage(Member)

Group = _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), dict(
  DESCRIPTOR = _GROUP,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Group)
  ))
_sym_db.RegisterMessage(Group)

ProtocolParameters = _reflection.GeneratedProtocolMessageType('ProtocolParameters', (_message.Message,), dict(
  DESCRIPTOR = _PROTOCOLPARAMETERS,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.ProtocolParameters)
  ))
_sym_db.RegisterMessage(ProtocolParameters)

Vtable = _reflection.GeneratedProtocolMessageType('Vtable', (_message.Message,), dict(
  DESCRIPTOR = _VTABLE,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Vtable)
  ))
_sym_db.RegisterMessage(Vtable)

Inst = _reflection.GeneratedProtocolMessageType('Inst', (_message.Message,), dict(
  DESCRIPTOR = _INST,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Inst)
  ))
_sym_db.RegisterMessage(Inst)


_INSTANCE.has_options = True
_INSTANCE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\274\005'))
_SERVICEANNOUNCEMENT.has_options = True
_SERVICEANNOUNCEMENT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\275\005'))
_ORIGINATOR.has_options = True
_ORIGINATOR._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\276\005'))
_ANERROR.has_options = True
_ANERROR._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\277\005'))
_PIN.has_options = True
_PIN._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\300\005'))
_SIGNAL.has_options = True
_SIGNAL._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\301\005'))
_PARAM.has_options = True
_PARAM._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\302\005'))
_FUNCTION.has_options = True
_FUNCTION._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\303\005'))
_THREAD.has_options = True
_THREAD._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\304\005'))
_COMPONENT.has_options = True
_COMPONENT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\305\005'))
_RING.has_options = True
_RING._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\306\005'))
_MEMBER.has_options = True
_MEMBER._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\307\005'))
_GROUP.has_options = True
_GROUP._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\310\005'))
_PROTOCOLPARAMETERS.has_options = True
_PROTOCOLPARAMETERS._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\311\005'))
_VTABLE.has_options = True
_VTABLE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\312\005'))
_INST.has_options = True
_INST._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\313\005'))
# @@protoc_insertion_point(module_scope)
