# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/task.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2
from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/task.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n\x1fmachinetalk/protobuf/task.proto\x12\x0bmachinetalk\x1a machinetalk/protobuf/types.proto\x1a!machinetalk/protobuf/nanopb.proto\"8\n\x0fTaskPlanExecute\x12\x0f\n\x07\x63ommand\x18\n \x01(\t\x12\x0c\n\x04line\x18\x1e \x01(\x0f:\x06\x92?\x03H\xb0\t\",\n\x13TaskPlanBlockDelete\x12\r\n\x05state\x18\n \x02(\x08:\x06\x92?\x03H\xb1\t\"-\n\x14TaskPlanOptionalStop\x12\r\n\x05state\x18\n \x02(\x08:\x06\x92?\x03H\xb2\t\"(\n\x0cTaskPlanOpen\x12\x10\n\x08\x66ilename\x18\n \x02(\t:\x06\x92?\x03H\xb3\t\"R\n\rTaskPlanReply\x12\'\n\x03\x63md\x18\n \x02(\x0e\x32\x1a.machinetalk.ContainerType\x12\x10\n\x08\x65rrormsg\x18\x14 \x01(\t:\x06\x92?\x03H\xb4\t\"#\n\tTaskReply\x12\x0e\n\x06ticket\x18\n \x02(\x07:\x06\x92?\x03H\xb5\t\"^\n\x0cTicketUpdate\x12\x0f\n\x07\x63ticket\x18\n \x02(\x07\x12\'\n\x06status\x18\x14 \x02(\x0e\x32\x17.machinetalk.RCS_STATUS\x12\x0c\n\x04text\x18\x1e \x01(\t:\x06\x92?\x03H\xb6\t')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_TASKPLANEXECUTE = _descriptor.Descriptor(
  name='TaskPlanExecute',
  full_name='machinetalk.TaskPlanExecute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='machinetalk.TaskPlanExecute.command', index=0,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line', full_name='machinetalk.TaskPlanExecute.line', index=1,
      number=30, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\260\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=173,
)


_TASKPLANBLOCKDELETE = _descriptor.Descriptor(
  name='TaskPlanBlockDelete',
  full_name='machinetalk.TaskPlanBlockDelete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='machinetalk.TaskPlanBlockDelete.state', index=0,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\261\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=219,
)


_TASKPLANOPTIONALSTOP = _descriptor.Descriptor(
  name='TaskPlanOptionalStop',
  full_name='machinetalk.TaskPlanOptionalStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='machinetalk.TaskPlanOptionalStop.state', index=0,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\262\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=266,
)


_TASKPLANOPEN = _descriptor.Descriptor(
  name='TaskPlanOpen',
  full_name='machinetalk.TaskPlanOpen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='machinetalk.TaskPlanOpen.filename', index=0,
      number=10, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\263\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=308,
)


_TASKPLANREPLY = _descriptor.Descriptor(
  name='TaskPlanReply',
  full_name='machinetalk.TaskPlanReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='machinetalk.TaskPlanReply.cmd', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errormsg', full_name='machinetalk.TaskPlanReply.errormsg', index=1,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\264\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=392,
)


_TASKREPLY = _descriptor.Descriptor(
  name='TaskReply',
  full_name='machinetalk.TaskReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='machinetalk.TaskReply.ticket', index=0,
      number=10, type=7, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\265\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=429,
)


_TICKETUPDATE = _descriptor.Descriptor(
  name='TicketUpdate',
  full_name='machinetalk.TicketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cticket', full_name='machinetalk.TicketUpdate.cticket', index=0,
      number=10, type=7, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='machinetalk.TicketUpdate.status', index=1,
      number=20, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='machinetalk.TicketUpdate.text', index=2,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\266\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=525,
)

_TASKPLANREPLY.fields_by_name['cmd'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._CONTAINERTYPE
_TICKETUPDATE.fields_by_name['status'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._RCS_STATUS
DESCRIPTOR.message_types_by_name['TaskPlanExecute'] = _TASKPLANEXECUTE
DESCRIPTOR.message_types_by_name['TaskPlanBlockDelete'] = _TASKPLANBLOCKDELETE
DESCRIPTOR.message_types_by_name['TaskPlanOptionalStop'] = _TASKPLANOPTIONALSTOP
DESCRIPTOR.message_types_by_name['TaskPlanOpen'] = _TASKPLANOPEN
DESCRIPTOR.message_types_by_name['TaskPlanReply'] = _TASKPLANREPLY
DESCRIPTOR.message_types_by_name['TaskReply'] = _TASKREPLY
DESCRIPTOR.message_types_by_name['TicketUpdate'] = _TICKETUPDATE

TaskPlanExecute = _reflection.GeneratedProtocolMessageType('TaskPlanExecute', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANEXECUTE,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanExecute)
  ))
_sym_db.RegisterMessage(TaskPlanExecute)

TaskPlanBlockDelete = _reflection.GeneratedProtocolMessageType('TaskPlanBlockDelete', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANBLOCKDELETE,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanBlockDelete)
  ))
_sym_db.RegisterMessage(TaskPlanBlockDelete)

TaskPlanOptionalStop = _reflection.GeneratedProtocolMessageType('TaskPlanOptionalStop', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANOPTIONALSTOP,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanOptionalStop)
  ))
_sym_db.RegisterMessage(TaskPlanOptionalStop)

TaskPlanOpen = _reflection.GeneratedProtocolMessageType('TaskPlanOpen', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANOPEN,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanOpen)
  ))
_sym_db.RegisterMessage(TaskPlanOpen)

TaskPlanReply = _reflection.GeneratedProtocolMessageType('TaskPlanReply', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANREPLY,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanReply)
  ))
_sym_db.RegisterMessage(TaskPlanReply)

TaskReply = _reflection.GeneratedProtocolMessageType('TaskReply', (_message.Message,), dict(
  DESCRIPTOR = _TASKREPLY,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskReply)
  ))
_sym_db.RegisterMessage(TaskReply)

TicketUpdate = _reflection.GeneratedProtocolMessageType('TicketUpdate', (_message.Message,), dict(
  DESCRIPTOR = _TICKETUPDATE,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TicketUpdate)
  ))
_sym_db.RegisterMessage(TicketUpdate)


_TASKPLANEXECUTE.has_options = True
_TASKPLANEXECUTE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\260\t'))
_TASKPLANBLOCKDELETE.has_options = True
_TASKPLANBLOCKDELETE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\261\t'))
_TASKPLANOPTIONALSTOP.has_options = True
_TASKPLANOPTIONALSTOP._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\262\t'))
_TASKPLANOPEN.has_options = True
_TASKPLANOPEN._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\263\t'))
_TASKPLANREPLY.has_options = True
_TASKPLANREPLY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\264\t'))
_TASKREPLY.has_options = True
_TASKREPLY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\265\t'))
_TICKETUPDATE.has_options = True
_TICKETUPDATE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\266\t'))
# @@protoc_insertion_point(module_scope)
