# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/preview.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/preview.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n\"machinetalk/protobuf/preview.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\"u\n\x08Position\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\x12\t\n\x01z\x18\x05 \x01(\x01\x12\t\n\x01\x61\x18\x06 \x01(\x01\x12\t\n\x01\x62\x18\x07 \x01(\x01\x12\t\n\x01\x63\x18\x08 \x01(\x01\x12\t\n\x01u\x18\t \x01(\x01\x12\t\n\x01v\x18\n \x01(\x01\x12\t\n\x01w\x18\x0b \x01(\x01:\x06\x92?\x03H\xa0\x06\"\xd9\x04\n\x07Preview\x12(\n\x04type\x18\x01 \x02(\x0e\x32\x1a.machinetalk.PreviewOpType\x12\x13\n\x0bline_number\x18\x02 \x01(\x05\x12\"\n\x03pos\x18\x03 \x01(\x0b\x32\x15.machinetalk.Position\x12\x11\n\tfirst_end\x18\x04 \x01(\x01\x12\x12\n\nsecond_end\x18\x05 \x01(\x01\x12\x12\n\nfirst_axis\x18\x06 \x01(\x01\x12\x13\n\x0bsecond_axis\x18\x07 \x01(\x01\x12\x10\n\x08rotation\x18\x08 \x01(\x05\x12\x16\n\x0e\x61xis_end_point\x18\t \x01(\x01\x12\x13\n\x0bxy_rotation\x18\n \x01(\x01\x12\r\n\x05plane\x18\x0b \x01(\x05\x12\x0c\n\x04rate\x18\x0c \x01(\x01\x12\x11\n\tfeed_mode\x18\r \x01(\x05\x12\x0c\n\x04time\x18\x0e \x01(\x01\x12\x0c\n\x04text\x18\x0f \x01(\t\x12\x15\n\rangular_units\x18\x65 \x01(\x01\x12\x14\n\x0clength_units\x18\x66 \x01(\x01\x12\x11\n\tprobetype\x18g \x01(\x05\x12\x33\n\x04kins\x18h \x01(\x0e\x32\x1b.machinetalk.KinematicsType:\x08KT_JOINT\x12\x10\n\x08\x61xismask\x18i \x01(\x05\x12\x10\n\x08g5_index\x18j \x01(\x05\x12\x0e\n\x06pocket\x18k \x01(\x05\x12&\n\x05stype\x18n \x01(\x0e\x32\x17.machinetalk.SourceType\x12\x10\n\x08\x66ilename\x18o \x01(\t\x12\x11\n\tcmdstring\x18p \x01(\t\x12\x12\n\ncall_level\x18q \x01(\x05:\x06\x92?\x03H\xa1\x06*=\n\x0eKinematicsType\x12\x0c\n\x08KT_JOINT\x10\x01\x12\x0f\n\x0bKT_TRIVKINS\x10\x02\x12\x0c\n\x08KT_DELTA\x10\x03*\xe3\x03\n\rPreviewOpType\x12\x15\n\x11PV_STRAIGHT_PROBE\x10\x01\x12\x10\n\x0cPV_RIGID_TAP\x10\x02\x12\x14\n\x10PV_STRAIGHT_FEED\x10\x03\x12\x0f\n\x0bPV_ARC_FEED\x10\x04\x12\x18\n\x14PV_STRAIGHT_TRAVERSE\x10\x05\x12\x15\n\x11PV_SET_G5X_OFFSET\x10\x06\x12\x15\n\x11PV_SET_G92_OFFSET\x10\x07\x12\x16\n\x12PV_SET_XY_ROTATION\x10\x08\x12\x13\n\x0fPV_SELECT_PLANE\x10\t\x12\x18\n\x14PV_SET_TRAVERSE_RATE\x10\n\x12\x14\n\x10PV_SET_FEED_RATE\x10\x0b\x12\x12\n\x0ePV_CHANGE_TOOL\x10\x0c\x12\x19\n\x15PV_CHANGE_TOOL_NUMBER\x10\r\x12\x0c\n\x08PV_DWELL\x10\x0e\x12\x0e\n\nPV_MESSAGE\x10\x0f\x12\x0e\n\nPV_COMMENT\x10\x10\x12\x16\n\x12PV_USE_TOOL_OFFSET\x10\x11\x12\x11\n\rPV_SET_PARAMS\x10\x12\x12\x14\n\x10PV_SET_FEED_MODE\x10\x13\x12\x15\n\x11PV_SOURCE_CONTEXT\x10\x14\x12\x14\n\x10PV_PREVIEW_START\x10\x15\x12\x12\n\x0ePV_PREVIEW_END\x10\x16*F\n\nSourceType\x12\x0f\n\x0bST_NGC_FILE\x10\x01\x12\x11\n\rST_NGC_STRING\x10\x02\x12\x14\n\x10ST_PYTHON_METHOD\x10\x03')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_KINEMATICSTYPE = _descriptor.EnumDescriptor(
  name='KinematicsType',
  full_name='machinetalk.KinematicsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KT_JOINT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KT_TRIVKINS', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KT_DELTA', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=809,
  serialized_end=870,
)
_sym_db.RegisterEnumDescriptor(_KINEMATICSTYPE)

KinematicsType = enum_type_wrapper.EnumTypeWrapper(_KINEMATICSTYPE)
_PREVIEWOPTYPE = _descriptor.EnumDescriptor(
  name='PreviewOpType',
  full_name='machinetalk.PreviewOpType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PV_STRAIGHT_PROBE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_RIGID_TAP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_STRAIGHT_FEED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_ARC_FEED', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_STRAIGHT_TRAVERSE', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_G5X_OFFSET', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_G92_OFFSET', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_XY_ROTATION', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SELECT_PLANE', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_TRAVERSE_RATE', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_FEED_RATE', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_CHANGE_TOOL', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_CHANGE_TOOL_NUMBER', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_DWELL', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_MESSAGE', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_COMMENT', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_USE_TOOL_OFFSET', index=16, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_PARAMS', index=17, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_FEED_MODE', index=18, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SOURCE_CONTEXT', index=19, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_PREVIEW_START', index=20, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_PREVIEW_END', index=21, number=22,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=873,
  serialized_end=1356,
)
_sym_db.RegisterEnumDescriptor(_PREVIEWOPTYPE)

PreviewOpType = enum_type_wrapper.EnumTypeWrapper(_PREVIEWOPTYPE)
_SOURCETYPE = _descriptor.EnumDescriptor(
  name='SourceType',
  full_name='machinetalk.SourceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ST_NGC_FILE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_NGC_STRING', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_PYTHON_METHOD', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1358,
  serialized_end=1428,
)
_sym_db.RegisterEnumDescriptor(_SOURCETYPE)

SourceType = enum_type_wrapper.EnumTypeWrapper(_SOURCETYPE)
KT_JOINT = 1
KT_TRIVKINS = 2
KT_DELTA = 3
PV_STRAIGHT_PROBE = 1
PV_RIGID_TAP = 2
PV_STRAIGHT_FEED = 3
PV_ARC_FEED = 4
PV_STRAIGHT_TRAVERSE = 5
PV_SET_G5X_OFFSET = 6
PV_SET_G92_OFFSET = 7
PV_SET_XY_ROTATION = 8
PV_SELECT_PLANE = 9
PV_SET_TRAVERSE_RATE = 10
PV_SET_FEED_RATE = 11
PV_CHANGE_TOOL = 12
PV_CHANGE_TOOL_NUMBER = 13
PV_DWELL = 14
PV_MESSAGE = 15
PV_COMMENT = 16
PV_USE_TOOL_OFFSET = 17
PV_SET_PARAMS = 18
PV_SET_FEED_MODE = 19
PV_SOURCE_CONTEXT = 20
PV_PREVIEW_START = 21
PV_PREVIEW_END = 22
ST_NGC_FILE = 1
ST_NGC_STRING = 2
ST_PYTHON_METHOD = 3



_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='machinetalk.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='machinetalk.Position.x', index=0,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='machinetalk.Position.y', index=1,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='machinetalk.Position.z', index=2,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='a', full_name='machinetalk.Position.a', index=3,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='machinetalk.Position.b', index=4,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c', full_name='machinetalk.Position.c', index=5,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='u', full_name='machinetalk.Position.u', index=6,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v', full_name='machinetalk.Position.v', index=7,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w', full_name='machinetalk.Position.w', index=8,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\240\006')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=203,
)


_PREVIEW = _descriptor.Descriptor(
  name='Preview',
  full_name='machinetalk.Preview',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Preview.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line_number', full_name='machinetalk.Preview.line_number', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pos', full_name='machinetalk.Preview.pos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_end', full_name='machinetalk.Preview.first_end', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second_end', full_name='machinetalk.Preview.second_end', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_axis', full_name='machinetalk.Preview.first_axis', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second_axis', full_name='machinetalk.Preview.second_axis', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='machinetalk.Preview.rotation', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axis_end_point', full_name='machinetalk.Preview.axis_end_point', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xy_rotation', full_name='machinetalk.Preview.xy_rotation', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='plane', full_name='machinetalk.Preview.plane', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate', full_name='machinetalk.Preview.rate', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feed_mode', full_name='machinetalk.Preview.feed_mode', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='machinetalk.Preview.time', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='machinetalk.Preview.text', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular_units', full_name='machinetalk.Preview.angular_units', index=15,
      number=101, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='length_units', full_name='machinetalk.Preview.length_units', index=16,
      number=102, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probetype', full_name='machinetalk.Preview.probetype', index=17,
      number=103, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kins', full_name='machinetalk.Preview.kins', index=18,
      number=104, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axismask', full_name='machinetalk.Preview.axismask', index=19,
      number=105, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g5_index', full_name='machinetalk.Preview.g5_index', index=20,
      number=106, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pocket', full_name='machinetalk.Preview.pocket', index=21,
      number=107, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stype', full_name='machinetalk.Preview.stype', index=22,
      number=110, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filename', full_name='machinetalk.Preview.filename', index=23,
      number=111, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cmdstring', full_name='machinetalk.Preview.cmdstring', index=24,
      number=112, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='call_level', full_name='machinetalk.Preview.call_level', index=25,
      number=113, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\241\006')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=807,
)

_PREVIEW.fields_by_name['type'].enum_type = _PREVIEWOPTYPE
_PREVIEW.fields_by_name['pos'].message_type = _POSITION
_PREVIEW.fields_by_name['kins'].enum_type = _KINEMATICSTYPE
_PREVIEW.fields_by_name['stype'].enum_type = _SOURCETYPE
DESCRIPTOR.message_types_by_name['Position'] = _POSITION
DESCRIPTOR.message_types_by_name['Preview'] = _PREVIEW
DESCRIPTOR.enum_types_by_name['KinematicsType'] = _KINEMATICSTYPE
DESCRIPTOR.enum_types_by_name['PreviewOpType'] = _PREVIEWOPTYPE
DESCRIPTOR.enum_types_by_name['SourceType'] = _SOURCETYPE

Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), dict(
  DESCRIPTOR = _POSITION,
  __module__ = 'machinetalk.protobuf.preview_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Position)
  ))
_sym_db.RegisterMessage(Position)

Preview = _reflection.GeneratedProtocolMessageType('Preview', (_message.Message,), dict(
  DESCRIPTOR = _PREVIEW,
  __module__ = 'machinetalk.protobuf.preview_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Preview)
  ))
_sym_db.RegisterMessage(Preview)


_POSITION.has_options = True
_POSITION._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\240\006'))
_PREVIEW.has_options = True
_PREVIEW._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\241\006'))
# @@protoc_insertion_point(module_scope)
